@@ -1,61 +1,21 @@
 /*
- * $Header: /home/cvs/jakarta-struts/contrib/struts-el/src/share/org/apache/strutsel/taglib/html/ELFrameTag.java,v 1.8 2003/04/23 03:11:18 dmkarr Exp $
- * $Revision: 1.8 $
- * $Date: 2003/04/23 03:11:18 $
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowledgement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/contrib/struts-el/src/share/org/apache/strutsel/taglib/html/ELFrameTag.java,v 1.12 2004/03/14 07:15:01 sraeburn Exp $
+ * $Revision: 1.12 $
+ * $Date: 2004/03/14 07:15:01 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.strutsel.taglib.html;
@@ -86,8 +46,7 @@ import org.apache.strutsel.taglib.utils.EvalHelper;
  * be specified as expressions utilizing the JavaServer Pages Standard Library
  * expression language.
  *
- * @author David M. Karr
- * @version $Revision: 1.8 $
+ * @version $Revision: 1.12 $
  */
 public class ELFrameTag extends FrameTag {
 
@@ -96,6 +55,11 @@ public class ELFrameTag extends FrameTag {
      * (Mapping set in associated BeanInfo class.)
      */
     private String actionExpr;
+    /**
+     * Instance variable mapped to "module" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    private String moduleExpr;
     /**
      * Instance variable mapped to "anchor" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -222,6 +186,11 @@ public class ELFrameTag extends FrameTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public String getActionExpr() { return (actionExpr); }
+    /**
+     * Getter method for "module" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public String getModuleExpr() { return (moduleExpr); }
     /**
      * Getter method for "anchor" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -348,6 +317,11 @@ public class ELFrameTag extends FrameTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public void setActionExpr(String actionExpr) { this.actionExpr = actionExpr; }
+    /**
+     * Setter method for "module" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public void setModuleExpr(String moduleExpr) { this.moduleExpr = moduleExpr; }
     /**
      * Setter method for "anchor" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -476,6 +450,7 @@ public class ELFrameTag extends FrameTag {
     {
         super.release();
         setActionExpr(null);
+        setModuleExpr(null);
         setAnchorExpr(null);
         setForwardExpr(null);
         setFrameborderExpr(null);
@@ -527,6 +502,10 @@ public class ELFrameTag extends FrameTag {
                                             this, pageContext)) != null)
             setAction(string);
 
+        if ((string = EvalHelper.evalString("module", getModuleExpr(),
+                                            this, pageContext)) != null)
+            setModule(string);
+
         if ((string = EvalHelper.evalString("anchor", getAnchorExpr(),
                                             this, pageContext)) != null)
             setAnchor(string);
@@ -553,11 +532,11 @@ public class ELFrameTag extends FrameTag {
 
         if ((integer = EvalHelper.evalInteger("marginheight", getMarginheightExpr(),
                                               this, pageContext)) != null)
-            setMarginheight(integer.intValue());
+            setMarginheight(integer);
 
         if ((integer = EvalHelper.evalInteger("marginwidth", getMarginwidthExpr(),
                                               this, pageContext)) != null)
-            setMarginwidth(integer.intValue());
+            setMarginwidth(integer);
 
         if ((string = EvalHelper.evalString("name", getNameExpr(),
                                             this, pageContext)) != null)
