@@ -1,61 +1,21 @@
 /*
- * $Header: /home/cvs/jakarta-struts/contrib/struts-el/src/share/org/apache/strutsel/taglib/html/ELImgTag.java,v 1.8 2003/03/09 05:47:23 dmkarr Exp $
- * $Revision: 1.8 $
- * $Date: 2003/03/09 05:47:23 $
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowledgement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/contrib/struts-el/src/share/org/apache/strutsel/taglib/html/ELImgTag.java,v 1.14 2004/03/14 07:15:01 sraeburn Exp $
+ * $Revision: 1.14 $
+ * $Date: 2004/03/14 07:15:01 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.strutsel.taglib.html;
@@ -83,16 +43,20 @@ import org.apache.strutsel.taglib.utils.EvalHelper;
  * be specified as expressions utilizing the JavaServer Pages Standard Library
  * expression language.
  *
- * @author David M. Karr
- * @version $Revision: 1.8 $
+ * @version $Revision: 1.14 $
  */
 public class ELImgTag extends ImgTag {
 
     /**
-     * Instance variable mapped to "accessKey" tag attribute.
+     * Instance variable mapped to "action" tag attribute.
      * (Mapping set in associated BeanInfo class.)
      */
-    private String accessKeyExpr;
+    private String actionExpr;
+    /**
+     * Instance variable mapped to "module" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    private String moduleExpr;
     /**
      * Instance variable mapped to "align" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -118,6 +82,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     private String bundleExpr;
+    /**
+     * Instance variable mapped to "contextRelative" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    private String contextRelativeExpr;
     /**
      * Instance variable mapped to "height" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -203,6 +172,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     private String onmouseupExpr;
+    /**
+     * Instance variable mapped to "paramId" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    private String paramIdExpr;
     /**
      * Instance variable mapped to "page" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -213,11 +187,6 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     private String pageKeyExpr;
-    /**
-     * Instance variable mapped to "paramId" tag attribute.
-     * (Mapping set in associated BeanInfo class.)
-     */
-    private String paramIdExpr;
     /**
      * Instance variable mapped to "paramName" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -278,6 +247,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     private String titleKeyExpr;
+    /**
+     * Instance variable mapped to "useLocalEncoding" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    private String useLocalEncodingExpr;
     /**
      * Instance variable mapped to "usemap" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -295,10 +269,15 @@ public class ELImgTag extends ImgTag {
     private String widthExpr;
 
     /**
-     * Getter method for "accessKey" tag attribute.
+     * Getter method for "action" tag attribute.
      * (Mapping set in associated BeanInfo class.)
      */
-    public String getAccesskeyExpr() { return (accessKeyExpr); }
+    public String getActionExpr() { return (actionExpr); }
+    /**
+     * Getter method for "module" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public String getModuleExpr() { return (moduleExpr); }
     /**
      * Getter method for "align" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -324,6 +303,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public String getBundleExpr() { return (bundleExpr); }
+    /**
+     * Getter method for "contextRelative" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public String getContextRelativeExpr() { return (contextRelativeExpr); }
     /**
      * Getter method for "height" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -409,6 +393,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public String getOnmouseupExpr() { return (onmouseupExpr); }
+    /**
+     * Getter method for "paramId" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public String getParamIdExpr() { return (paramIdExpr); }
     /**
      * Getter method for "page" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -419,11 +408,6 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public String getPageKeyExpr() { return (pageKeyExpr); }
-    /**
-     * Getter method for "paramId" tag attribute.
-     * (Mapping set in associated BeanInfo class.)
-     */
-    public String getParamIdExpr() { return (paramIdExpr); }
     /**
      * Getter method for "paramName" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -484,6 +468,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public String getTitleKeyExpr() { return (titleKeyExpr); }
+    /**
+     * Getter method for "useLocalEncoding" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public String getUseLocalEncodingExpr() { return (useLocalEncodingExpr); }
     /**
      * Getter method for "usemap" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -501,10 +490,15 @@ public class ELImgTag extends ImgTag {
     public String getWidthExpr() { return (widthExpr); }
 
     /**
-     * Setter method for "accessKey" tag attribute.
+     * Setter method for "action" tag attribute.
      * (Mapping set in associated BeanInfo class.)
      */
-    public void setAccesskeyExpr(String accessKeyExpr) { this.accessKeyExpr = accessKeyExpr; }
+    public void setActionExpr(String actionExpr) { this.actionExpr = actionExpr; }
+    /**
+     * Setter method for "module" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public void setModuleExpr(String moduleExpr) { this.moduleExpr = moduleExpr; }
     /**
      * Setter method for "align" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -530,6 +524,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public void setBundleExpr(String bundleExpr) { this.bundleExpr = bundleExpr; }
+    /**
+     * Setter method for "contextRelative" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public void setContextRelativeExpr(String contextRelativeExpr) { this.contextRelativeExpr = contextRelativeExpr; }
     /**
      * Setter method for "height" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -615,6 +614,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public void setOnmouseupExpr(String onmouseupExpr) { this.onmouseupExpr = onmouseupExpr; }
+    /**
+     * Setter method for "paramId" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public void setParamIdExpr(String paramIdExpr) { this.paramIdExpr = paramIdExpr; }
     /**
      * Setter method for "page" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -625,11 +629,6 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public void setPageKeyExpr(String pageKeyExpr) { this.pageKeyExpr = pageKeyExpr; }
-    /**
-     * Setter method for "paramId" tag attribute.
-     * (Mapping set in associated BeanInfo class.)
-     */
-    public void setParamIdExpr(String paramIdExpr) { this.paramIdExpr = paramIdExpr; }
     /**
      * Setter method for "paramName" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -690,6 +689,11 @@ public class ELImgTag extends ImgTag {
      * (Mapping set in associated BeanInfo class.)
      */
     public void setTitleKeyExpr(String titleKeyExpr) { this.titleKeyExpr = titleKeyExpr; }
+    /**
+     * Setter method for "useLocalEncoding" tag attribute.
+     * (Mapping set in associated BeanInfo class.)
+     */
+    public void setUseLocalEncodingExpr(String useLocalEncodingExpr) { this.useLocalEncodingExpr = useLocalEncodingExpr; }
     /**
      * Setter method for "usemap" tag attribute.
      * (Mapping set in associated BeanInfo class.)
@@ -712,12 +716,14 @@ public class ELImgTag extends ImgTag {
     public void release()
     {
         super.release();
-        setAccesskeyExpr(null);
+        setActionExpr(null);
+        setModuleExpr(null);
         setAlignExpr(null);
         setAltExpr(null);
         setAltKeyExpr(null);
         setBorderExpr(null);
         setBundleExpr(null);
+        setContextRelativeExpr(null);
         setHeightExpr(null);
         setHspaceExpr(null);
         setImageNameExpr(null);
@@ -750,6 +756,7 @@ public class ELImgTag extends ImgTag {
         setStyleIdExpr(null);
         setTitleExpr(null);
         setTitleKeyExpr(null);
+        setUseLocalEncodingExpr(null);
         setUsemapExpr(null);
         setVspaceExpr(null);
         setWidthExpr(null);
@@ -773,10 +780,15 @@ public class ELImgTag extends ImgTag {
      */
     private void evaluateExpressions() throws JspException {
         String  string  = null;
+        Boolean bool    = null;
 
-        if ((string = EvalHelper.evalString("accessKey", getAccesskeyExpr(),
+        if ((string = EvalHelper.evalString("action", getActionExpr(),
                                             this, pageContext)) != null)
-            setAccesskey(string);
+            setAction(string);
+
+        if ((string = EvalHelper.evalString("module", getModuleExpr(),
+                                            this, pageContext)) != null)
+            setModule(string);
 
         if ((string = EvalHelper.evalString("align", getAlignExpr(),
                                             this, pageContext)) != null)
@@ -798,6 +810,10 @@ public class ELImgTag extends ImgTag {
                                             this, pageContext)) != null)
             setBundle(string);
 
+        if ((string = EvalHelper.evalString("contextRelative", getContextRelativeExpr(),
+                                            this, pageContext)) != null)
+            setContextRelative(string);
+
         if ((string = EvalHelper.evalString("height", getHeightExpr(),
                                             this, pageContext)) != null)
             setHeight(string);
@@ -868,6 +884,10 @@ public class ELImgTag extends ImgTag {
                                             this, pageContext)) != null)
             setOnmouseup(string);
 
+        if ((string = EvalHelper.evalString("paramId", getParamIdExpr(),
+                                            this, pageContext)) != null)
+            setParamId(string);
+
         if ((string = EvalHelper.evalString("page", getPageExpr(),
                                             this, pageContext)) != null)
             setPage(string);
@@ -876,10 +896,6 @@ public class ELImgTag extends ImgTag {
                                             this, pageContext)) != null)
             setPageKey(string);
 
-        if ((string = EvalHelper.evalString("paramId", getParamIdExpr(),
-                                            this, pageContext)) != null)
-            setParamId(string);
-
         if ((string = EvalHelper.evalString("paramName", getParamNameExpr(),
                                             this, pageContext)) != null)
             setParamName(string);
@@ -928,6 +944,10 @@ public class ELImgTag extends ImgTag {
                                             this, pageContext)) != null)
             setTitleKey(string);
 
+        if ((bool = EvalHelper.evalBoolean("useLocalEncoding", getUseLocalEncodingExpr(),
+                                            this, pageContext)) != null)
+            setUseLocalEncoding(bool.booleanValue());
+
         if ((string = EvalHelper.evalString("usemap", getUsemapExpr(),
                                             this, pageContext)) != null)
             setUsemap(string);
