@@ -1,75 +1,34 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/action/DynaActionForm.java,v 1.8 2003/04/10 02:35:28 dgraham Exp $
- * $Revision: 1.8 $
- * $Date: 2003/04/10 02:35:28 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/action/DynaActionForm.java,v 1.16 2004/08/10 02:47:39 niallp Exp $
+ * $Revision: 1.16 $
+ * $Date: 2004/08/10 02:47:39 $
  *
+ * Copyright 2000-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
-
 package org.apache.struts.action;
 
-
 import java.lang.reflect.Array;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+
 import javax.servlet.ServletRequest;
 import javax.servlet.http.HttpServletRequest;
+
 import org.apache.commons.beanutils.ConversionException;
 import org.apache.commons.beanutils.DynaBean;
 import org.apache.commons.beanutils.DynaClass;
@@ -84,17 +43,15 @@ import org.apache.struts.config.FormPropertyConfig;
  * developer to create a Java class for each type of form bean.</p>
  *
  * <p><strong>USAGE NOTE</strong> - Since Struts 1.1, the
- * <code>reset()</code> method no longer initializes property values to those
+ * <code>reset</code> method no longer initializes property values to those
  * specified in <code>&lt;form-property&gt;</code> elements in the Struts
  * module configuration file.  If you wish to utilize that behavior, the
  * simplest solution is to subclass <code>DynaActionForm</code> and call
- * the <code>initialize()</code> method inside it.</p>
+ * the <code>initialize</code> method inside it.</p>
  *
- * @author Craig R. McClanahan
- * @version $Revision: 1.8 $ $Date: 2003/04/10 02:35:28 $
+ * @version $Revision: 1.16 $ $Date: 2004/08/10 02:47:39 $
  * @since Struts 1.1
  */
-
 public class DynaActionForm extends ActionForm implements DynaBean {
 
 
@@ -102,14 +59,15 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * The DynaActionFormClass with which we are associated.
+     * <p>The <code>DynaActionFormClass</code> with which we are associated.
+     * </p>
      */
     protected DynaActionFormClass dynaClass = null;
 
 
     /**
-     * The set of property values for this DynaActionForm, keyed by
-     * property name.
+     * <p>The set of property values for this <code>DynaActionForm</code>,
+     * keyed by property name.</p>
      */
     protected HashMap dynaValues = new HashMap();
 
@@ -123,8 +81,6 @@ public class DynaActionForm extends ActionForm implements DynaBean {
      * definition of this <code>DynaActionForm</code>.</p>
      *
      * @param mapping The mapping used to select this instance
-     *
-     * @since Struts 1.1
      */
     public void initialize(ActionMapping mapping) {
 
@@ -137,6 +93,12 @@ public class DynaActionForm extends ActionForm implements DynaBean {
         if (config == null) {
             return;
         }
+
+        initialize(config);
+    }
+
+    public void initialize(FormBeanConfig config) {
+
         FormPropertyConfig props[] = config.findFormPropertyConfigs();
         for (int i = 0; i < props.length; i++) {
             set(props[i].getName(), props[i].initial());
@@ -145,12 +107,14 @@ public class DynaActionForm extends ActionForm implements DynaBean {
     }
 
 
+    // :FIXME: Is there any point in retaining these reset methods
+    // since they now simply replicate the superclass behavior?
 
     /**
-     * <p>Reset all bean properties to their default state.  This method is
-     * called before the properties are repopulated by the controller
-     * servlet.</p>
-     * 
+     * <p>Reset bean properties to their default state, as needed.
+     * This method is called before the properties are repopulated by
+     * the controller.</p>
+     *
      * <p>The default implementation attempts to forward to the HTTP
      * version of this method.</p>
      *
@@ -158,35 +122,26 @@ public class DynaActionForm extends ActionForm implements DynaBean {
      * @param request The servlet request we are processing
      */
     public void reset(ActionMapping mapping, ServletRequest request) {
-
-        try {
-            reset(mapping, (HttpServletRequest) request);
-        } catch (ClassCastException e) {
-            ;
-        }
-
+        super.reset(mapping,request);
     }
 
 
     /**
-     * <p>Reset all bean properties to their default state.  This method is
-     * called before the properties are repopulated by the controller servlet.
-     * </p>
-     * 
+     * <p>Reset bean properties to their default state, as needed.  This method is
+     * called before the properties are repopulated by the controller.</p>
+     *
      * <p>The default implementation (since Struts 1.1) does nothing.
      * Subclasses may override this method to reset bean properties to
-     * default values, or the <code>initialize()</code> method may be used to
+     * default values, or the <code>initialize</code> method may be used to
      * initialize property values to those provided in the form property
-     * configuration information (which was the previous behavior of
-     * this method).</p>
+     * configuration information (which was the behavior of
+     * this method in some release candidates).</p>
      *
      * @param mapping The mapping used to select this instance
      * @param request The servlet request we are processing
      */
     public void reset(ActionMapping mapping, HttpServletRequest request) {
-
-        ;       // Default implementation does nothing
-
+        super.reset(mapping,request);
     }
 
 
@@ -194,8 +149,8 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Indicates if the specified mapped property contain a value for the specified
-     * key value.
+     * <p>Indicates if the specified mapped property contain a value for the
+     * specified key value.</p>
      *
      * @param name Name of the property to check
      * @param key Name of the key to check
@@ -220,7 +175,7 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Return the value of a simple property with the specified name.
+     * <p>Return the value of a simple property with the specified name.</p>
      *
      * @param name Name of the property whose value is to be retrieved
      *
@@ -235,7 +190,7 @@ public class DynaActionForm extends ActionForm implements DynaBean {
         Object value = dynaValues.get(name);
         if (value != null) {
             return (value);
-        } 
+        }
 
         // Return a null value for a non-primitive property
         Class type = getDynaProperty(name).getType();
@@ -255,13 +210,13 @@ public class DynaActionForm extends ActionForm implements DynaBean {
         } else if (type == Character.TYPE) {
             return (new Character((char) 0));
         } else if (type == Double.TYPE) {
-            return (new Double((double) 0.0));
+            return (new Double(0.0));
         } else if (type == Float.TYPE) {
             return (new Float((float) 0.0));
         } else if (type == Integer.TYPE) {
-            return (new Integer((int) 0));
+            return (new Integer(0));
         } else if (type == Long.TYPE) {
-            return (new Long((int) 0));
+            return (new Long(0));
         } else if (type == Short.TYPE) {
             return (new Short((short) 0));
         } else {
@@ -272,7 +227,8 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Return the value of an indexed property with the specified name.
+     * <p>Return the value of an indexed property with the specified name.
+     * </p>
      *
      * @param name Name of the property whose value is to be retrieved
      * @param index Index of the value to be retrieved
@@ -305,8 +261,9 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Return the value of a mapped property with the specified name,
+     * <p>Return the value of a mapped property with the specified name,
      * or <code>null</code> if there is no value for the specified key.
+     * </p>
      *
      * @param name Name of the property whose value is to be retrieved
      * @param key Key of the value to be retrieved
@@ -333,8 +290,50 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Return the <code>DynaClass</code> instance that describes the set of
-     * properties available for this DynaBean.
+     * <p>Return the value of a <code>String</code> property with the specified
+     * name. This is equivalent to calling
+     * <code>(String) dynaForm.get(name)</code>.</p>
+     *
+     * @param name Name of the property whose value is to be retrieved
+     *
+     * @throws IllegalArgumentException if there is no property
+     *  of the specified name
+     * @throws NullPointerException if the type specified for the
+     *  property is invalid
+     * @throws ClassCastException if the property is not a String.
+     * @since Struts 1.2
+     */
+    public String getString(String name) {
+
+        return (String) this.get(name);
+
+    }
+
+
+    /**
+     * <p>Return the value of a <code>String[]</code> property with the
+     * specified name. This is equivalent to calling
+     * <code>(String[]) dynaForm.get(name)</code>.</p>
+     *
+     * @param name Name of the property whose value is to be retrieved
+     *
+     * @throws IllegalArgumentException if there is no property
+     *  of the specified name
+     * @throws NullPointerException if the type specified for the
+     *  property is invalid
+     * @throws ClassCastException if the property is not a String[].
+     * @since Struts 1.2
+     */
+    public String[] getStrings(String name) {
+
+        return (String[]) this.get(name);
+
+    }
+
+
+    /**
+     * <p>Return the <code>DynaClass</code> instance that describes the set
+     * of properties available for this <code>DynaBean</code>.</p>
      */
     public DynaClass getDynaClass() {
 
@@ -342,13 +341,14 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
     }
 
+
     /**
-     * Returns the <code>Map</code> containing the property values.  This is
+     * <p>Returns the <code>Map</code> containing the property values.  This is
      * done mostly to facilitate accessing the <code>DynaActionForm</code>
      * through JavaBeans accessors, in order to use the JavaServer Pages
-     * Standard Tag Library.
-     *<p>
-     * For instance, the normal JSTL EL syntax for accessing an
+     * Standard Tag Library (JSTL).</p>
+     *
+     * <p>For instance, the normal JSTL EL syntax for accessing an
      * <code>ActionForm</code> would be something like this:
      * <pre>
      *  ${formbean.prop}</pre>
@@ -357,17 +357,18 @@ public class DynaActionForm extends ActionForm implements DynaBean {
      * <code>getMap()</code> method):
      * <pre>
      *  ${dynabean.map.prop}</pre>
+     * </p>
      */
     public Map getMap() {
 
         return (dynaValues);
 
     }
-    
+
 
     /**
-     * Remove any existing value for the specified key on the
-     * specified mapped property.
+     * <p>Remove any existing value for the specified key on the
+     * specified mapped property.</p>
      *
      * @param name Name of the property for which a value is to
      *  be removed
@@ -393,7 +394,7 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Set the value of a simple property with the specified name.
+     * <p>Set the value of a simple property with the specified name.</p>
      *
      * @param name Name of the property whose value is to be set
      * @param value Value to which this property is to be set
@@ -432,7 +433,7 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Set the value of an indexed property with the specified name.
+     * <p>Set the value of an indexed property with the specified name.</p>
      *
      * @param name Name of the property whose value is to be set
      * @param index Index of the property to be set
@@ -470,7 +471,7 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Set the value of a mapped property with the specified name.
+     * <p>Set the value of a mapped property with the specified name.</p>
      *
      * @param name Name of the property whose value is to be set
      * @param key Key of the property to be set
@@ -503,7 +504,7 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Render a String representation of this object.
+     * <p>Render a String representation of this object.</p>
      */
     public String toString() {
 
@@ -549,7 +550,7 @@ public class DynaActionForm extends ActionForm implements DynaBean {
                         sb.append(',');
                     }
                     n++;
-                    String key = (String) keys.next();
+                    Object key = keys.next();
                     sb.append(key);
                     sb.append('=');
                     sb.append(((Map) value).get(key));
@@ -569,7 +570,8 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Set the DynaActionFormClass instance that we are associated with.
+     * <p>Set the <code>DynaActionFormClass</code> instance with which we are
+     * associated.</p>
      *
      * @param dynaClass The DynaActionFormClass instance for this bean
      */
@@ -584,7 +586,7 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Return the property descriptor for the specified property name.
+     * <p>Return the property descriptor for the specified property name.</p>
      *
      * @param name Name of the property for which to retrieve the descriptor
      *
@@ -604,7 +606,8 @@ public class DynaActionForm extends ActionForm implements DynaBean {
 
 
     /**
-     * Indicates if an object of the source class is assignable to the destination class.
+     * <p>Indicates if an object of the source class is assignable to the
+     * destination class.</p>
      *
      * @param dest Destination class
      * @param source Source class
