@@ -1,68 +1,25 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/action/RequestProcessor.java,v 1.30 2003/04/19 01:16:29 dgraham Exp $
- * $Revision: 1.30 $
- * $Date: 2003/04/19 01:16:29 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/action/RequestProcessor.java,v 1.45 2004/04/25 02:29:41 husted Exp $
+ * $Revision: 1.45 $
+ * $Date: 2004/04/25 02:29:41 $
  *
+ * Copyright 2000-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
-
 package org.apache.struts.action;
 
-
 import java.io.IOException;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -87,20 +44,16 @@ import org.apache.struts.upload.MultipartRequestWrapper;
 import org.apache.struts.util.MessageResources;
 import org.apache.struts.util.RequestUtils;
 
-
 /**
  * <p><strong>RequestProcessor</strong> contains the processing logic that
- * the Struts controller servlet performs as it receives each servlet request
- * from the container.  You can customize the request processing behavior by
+ * the @link(ActionServlet) performs as it receives each servlet request
+ * from the container. You can customize the request processing behavior by
  * subclassing this class and overriding the method(s) whose behavior you are
  * interested in changing.</p>
  *
- * @author Craig R. McClanahan
- * @author Cedric Dumoulin
- * @version $Revision: 1.30 $ $Date: 2003/04/19 01:16:29 $
+ * @version $Revision: 1.45 $ $Date: 2004/04/25 02:29:41 $
  * @since Struts 1.1
  */
-
 public class RequestProcessor {
 
 
@@ -108,16 +61,16 @@ public class RequestProcessor {
 
 
     /**
-     * The request attribute under which the path information is stored for
-     * processing during a RequestDispatcher.include() call.
+     * <p>The request attribute under which the path information is stored for
+     * processing during a <code>RequestDispatcher.include</code> call.</p>
      */
     public static final String INCLUDE_PATH_INFO =
         "javax.servlet.include.path_info";
 
 
     /**
-     * The request attribute under which the servlet path information is stored
-     * for processing during a RequestDispatcher.include() call.
+     * <p>The request attribute under which the servlet path information is stored
+     * for processing during a <code>RequestDispatcher.include</code> call.</p>
      */
     public static final String INCLUDE_SERVLET_PATH =
         "javax.servlet.include.servlet_path";
@@ -127,32 +80,27 @@ public class RequestProcessor {
 
 
     /**
-     * The set of Action instances that have been created and initialized,
-     * keyed by the fully qualified Java class name of the Action class.
+     * <p>The set of <code>Action</code> instances that have been created and
+     * initialized, keyed by the fully qualified Java class name of the
+     * <code>Action</code> class.</p>
      */
     protected HashMap actions = new HashMap();
 
 
     /**
-     * The ModuleConfiguration we are associated with.
-     * @deprecated use moduleConfig instead.
-     */
-    protected ModuleConfig appConfig = null;
-
-    /**
-     * The ModuleConfiguration we are associated with.
+     * <p>The <code>ModuleConfiguration</code> with which we are associated.</p>
      */
     protected ModuleConfig moduleConfig = null;
 
 
     /**
-     * Commons Logging instance.
+     * <p>Commons Logging instance.</p>
      */
     protected static Log log = LogFactory.getLog(RequestProcessor.class);
 
 
     /**
-     * The controller servlet we are associated with.
+     * <p>The servlet with which we are associated.</p>
      */
     protected ActionServlet servlet = null;
 
@@ -161,7 +109,7 @@ public class RequestProcessor {
 
 
     /**
-     * Clean up in preparation for a shutdown of this application.
+     * <p>Clean up in preparation for a shutdown of this application.</p>
      */
     public void destroy() {
 
@@ -179,7 +127,7 @@ public class RequestProcessor {
 
 
     /**
-     * Initialize this request processor instance.
+     * <p>Initialize this request processor instance.</p>
      *
      * @param servlet The ActionServlet we are associated with
      * @param moduleConfig The ModuleConfig we are associated with.
@@ -192,16 +140,16 @@ public class RequestProcessor {
         synchronized (actions) {
             actions.clear();
         }
+        
         this.servlet = servlet;
-        this.appConfig = moduleConfig;
         this.moduleConfig = moduleConfig;
-
     }
 
 
     /**
      * <p>Process an <code>HttpServletRequest</code> and create the
-     * corresponding <code>HttpServletResponse</code>.</p>
+     * corresponding <code>HttpServletResponse</code> or dispatch
+     * to another resource.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -221,6 +169,7 @@ public class RequestProcessor {
         if (path == null) {
             return;
         }
+        
         if (log.isDebugEnabled()) {
             log.debug("Processing a '" + request.getMethod() +
                       "' for path '" + path + "'");
@@ -237,6 +186,8 @@ public class RequestProcessor {
         if (!processPreprocess(request, response)) {
             return;
         }
+        
+        this.processCachedMessages(request, response);
 
         // Identify the mapping for this request
         ActionMapping mapping = processMapping(request, response, path);
@@ -260,6 +211,7 @@ public class RequestProcessor {
         if (!processForward(request, response, mapping)) {
             return;
         }
+        
         if (!processInclude(request, response, mapping)) {
             return;
         }
@@ -285,8 +237,8 @@ public class RequestProcessor {
 
 
     /**
-     * Return an <code>Action</code> instance that will be used to process
-     * the current request, creating a new one if necessary.
+     * <p>Return an <code>Action</code> instance that will be used to process
+     * the current request, creating a new one if necessary.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -304,7 +256,11 @@ public class RequestProcessor {
         if (log.isDebugEnabled()) {
             log.debug(" Looking for Action instance for class " + className);
         }
-        
+
+        // :TODO: If there were a mapping property indicating whether
+        // an Action were a singleton or not ([true]),
+        // could we just instantiate and return a new instance here?
+
         Action instance = null;
         synchronized (actions) {
 
@@ -324,8 +280,8 @@ public class RequestProcessor {
             
             try {
                 instance = (Action) RequestUtils.applicationInstance(className);
-                // TODO Maybe we should propagate this exception instead of returning
-                // null.
+                // :TODO: Maybe we should propagate this exception
+                // instead of returning null.
             } catch (Exception e) {
                 log.error(
                     getInternal().getMessage("actionCreate", mapping.getPath()),
@@ -348,9 +304,10 @@ public class RequestProcessor {
 
 
     /**
-     * Retrieve and return the <code>ActionForm</code> bean associated with
-     * this mapping, creating and stashing one if necessary.  If there is no
-     * form bean associated with this mapping, return <code>null</code>.
+     * <p>Retrieve and return the <code>ActionForm</code> associated with
+     * this mapping, creating and retaining one if necessary. If there is no
+     * <code>ActionForm</code> associated with this mapping, return
+     * <code>null</code>.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -360,7 +317,7 @@ public class RequestProcessor {
                                            HttpServletResponse response,
                                            ActionMapping mapping) {
 
-        // Create (if necessary a form bean to use
+        // Create (if necessary) a form bean to use
         ActionForm instance = RequestUtils.createActionForm
             (request, mapping, moduleConfig, servlet);
         if (instance == null) {
@@ -384,34 +341,10 @@ public class RequestProcessor {
     }
 
 
-
     /**
-     * Forward or redirect to the specified destination, by the specified
-     * mechanism.
-     *
-     * This method takes the old ActionForward object as parameter. User should
-     * use {@link #processForwardConfig(HttpServletRequest, HttpServletResponse,ForwardConfig)} when possible.
-     * @param request The servlet request we are processing
-     * @param response The servlet response we are creating
-     * @param forward The ActionForward controlling where we go next
-     *
-     * @exception IOException if an input/output error occurs
-     * @exception ServletException if a servlet exception occurs
-     * @deprecated Use processForwardConfig() instead.
-     */
-    protected void processActionForward(HttpServletRequest request,
-                                        HttpServletResponse response,
-                                        ActionForward forward)
-        throws IOException, ServletException {
-
-        processForwardConfig( request, response, forward );
-
-    }
-
-
-    /**
-     * Forward or redirect to the specified destination, by the specified
-     * mechanism.  This method uses a ForwardConfig object instead an ActionForward.
+     * <p>Forward or redirect to the specified destination, by the specified
+     * mechanism.  This method uses a <code>ForwardConfig</code> object instead
+     * an <code>ActionForward</code>.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -439,7 +372,7 @@ public class RequestProcessor {
         // paths not starting with / should be passed through without any processing
         // (ie. they're absolute)
         if (forwardPath.startsWith("/")) {
-            uri = RequestUtils.forwardURL(request, forward);    // get module relative uri
+            uri = RequestUtils.forwardURL(request, forward, null);    // get module relative uri
         } else {
             uri = forwardPath;
         }
@@ -458,10 +391,14 @@ public class RequestProcessor {
     }
 
 
+    // :FIXME: if Action.execute throws Exception, and Action.process has been removed,
+    // should the process* methods still throw IOException, ServletException?
+
     /**
-     * Ask the specified <code>Action</code> instance to handle this
-     * request.  Return the <code>ActionForward</code> instance (if any)
+     * <P>Ask the specified <code>Action</code> instance to handle this
+     * request. Return the <code>ActionForward</code> instance (if any)
      * returned by the called <code>Action</code> for further processing.
+     * </P>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -488,14 +425,48 @@ public class RequestProcessor {
         }
 
     }
+    
+    /**
+     * <p>Removes any <code>ActionMessages</code> object stored in the session under
+     * <code>Globals.MESSAGE_KEY</code> if the messages' 
+     * <code>isAccessed</code> method returns true.  This allows messages to
+     * be stored in the session, display one time, and be released here.</p>
+     *
+     * @param request The servlet request we are processing.
+     * @param response The servlet response we are creating.
+     *
+     * @since Struts 1.2
+     */
+    protected void processCachedMessages(
+
+        HttpServletRequest request,
+        HttpServletResponse response) {
+
+        HttpSession session = request.getSession(false);
+        if (session == null) {
+            return;
+        }
+
+        ActionMessages messages =
+            (ActionMessages) session.getAttribute(Globals.MESSAGE_KEY);
+
+        if (messages == null) {
+            return;
+        }
+
+        if (messages.isAccessed()) {
+            session.removeAttribute(Globals.MESSAGE_KEY);
+        }
+
+    }
 
 
     /**
-     * Set the default content type (with optional character encoding) for
+     * <p>Set the default content type (with optional character encoding) for
      * all responses if requested.  <strong>NOTE</strong> - This header will
      * be overridden automatically if a
-     * <code>RequestDispatcher.forward()</code> call is
-     * ultimately invoked.
+     * <code>RequestDispatcher.forward</code> call is
+     * ultimately invoked.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -512,9 +483,9 @@ public class RequestProcessor {
 
 
     /**
-     * Ask our exception handler to handle the exception.  Return the
+     * <p>Ask our exception handler to handle the exception. Return the
      * <code>ActionForward</code> instance (if any) returned by the
-     * called <code>ExceptionHandler</code>.
+     * called <code>ExceptionHandler</code>.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are processing
@@ -560,9 +531,9 @@ public class RequestProcessor {
 
 
     /**
-     * Process a forward requested by this mapping (if any).  Return
+     * <p>Process a forward requested by this mapping (if any). Return
      * <code>true</code> if standard processing should continue, or
-     * <code>false</code> if we have already handled this request.
+     * <code>false</code> if we have already handled this request.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -586,9 +557,9 @@ public class RequestProcessor {
 
 
     /**
-     * Process an include requested by this mapping (if any).  Return
+     * <p>Process an include requested by this mapping (if any). Return
      * <code>true</code> if standard processing should continue, or
-     * <code>false</code> if we have already handled this request.
+     * <code>false</code> if we have already handled this request.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -612,9 +583,9 @@ public class RequestProcessor {
 
 
     /**
-     * Automatically select a Locale for the current user, if requested.
+     * <p>Automatically select a <code>Locale</code> for the current user, if requested.
      * <strong>NOTE</strong> - configuring Locale selection will trigger
-     * the creation of a new <code>HttpSession</code> if necessary.
+     * the creation of a new <code>HttpSession</code> if necessary.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -646,9 +617,9 @@ public class RequestProcessor {
 
 
     /**
-     * Select the mapping used to process the selection path for this request.
+     * <p>Select the mapping used to process the selection path for this request.
      * If no mapping can be identified, create an error response and return
-     * <code>null</code>.
+     * <code>null</code>.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -661,9 +632,11 @@ public class RequestProcessor {
                                            String path)
         throws IOException {
 
-        // Is there a directly defined mapping for this path?
+        // Is there a mapping for this path?
         ActionMapping mapping = (ActionMapping)
             moduleConfig.findActionConfig(path);
+
+        // If a mapping is found, put it in the request and return it
         if (mapping != null) {
             request.setAttribute(Globals.MAPPING_KEY, mapping);
             return (mapping);
@@ -680,18 +653,17 @@ public class RequestProcessor {
         }
 
         // No mapping can be found to process this request
-        log.error(getInternal().getMessage("processInvalid", path));
-        response.sendError(HttpServletResponse.SC_BAD_REQUEST,
-                           getInternal().getMessage
-                           ("processInvalid", path));
-        return (null);
-
+        String msg = getInternal().getMessage("processInvalid", path);
+        log.error(msg);
+        response.sendError(HttpServletResponse.SC_NOT_FOUND, msg);
+        
+        return null;
     }
 
 
     /**
-     * If this is a multipart request, wrap it with a special wrapper.
-     * Otherwise, return the request unchanged.
+     * <p>If this is a multipart request, wrap it with a special wrapper.
+     * Otherwise, return the request unchanged.</p>
      *
      * @param request The HttpServletRequest we are processing
      */
@@ -713,10 +685,10 @@ public class RequestProcessor {
 
 
     /**
-     * Set the no-cache headers for all responses, if requested.
+     * <p>Set the no-cache headers for all responses, if requested.
      * <strong>NOTE</strong> - This header will be overridden
-     * automatically if a <code>RequestDispatcher.forward()</code> call is
-     * ultimately invoked.
+     * automatically if a <code>RequestDispatcher.forward</code> call is
+     * ultimately invoked.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -726,7 +698,7 @@ public class RequestProcessor {
 
         if (moduleConfig.getControllerConfig().getNocache()) {
             response.setHeader("Pragma", "No-cache");
-            response.setHeader("Cache-Control", "no-cache");
+            response.setHeader("Cache-Control", "no-cache,no-store,max-age=0");
             response.setDateHeader("Expires", 1);
         }
 
@@ -734,10 +706,10 @@ public class RequestProcessor {
 
 
     /**
-     * Identify and return the path component (from the request URI) that
-     * we will use to select an ActionMapping to dispatch with.  If no such
-     * path can be identified, create an error response and return
-     * <code>null</code>.
+     * <p>Identify and return the path component (from the request URI) that
+     * we will use to select an <code>ActionMapping</code> with which to dispatch.
+     * If no such path can be identified, create an error response and return
+     * <code>null</code>.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -766,13 +738,15 @@ public class RequestProcessor {
         }
         String prefix = moduleConfig.getPrefix();
         if (!path.startsWith(prefix)) {
-            log.error(getInternal().getMessage("processPath",
-                                         request.getRequestURI()));
-            response.sendError(HttpServletResponse.SC_BAD_REQUEST,
-                               getInternal().getMessage
-                               ("processPath", request.getRequestURI()));
-            return (null);
+            String msg =
+                getInternal().getMessage("processPath", request.getRequestURI());
+            
+            log.error(msg);
+            response.sendError(HttpServletResponse.SC_BAD_REQUEST, msg);
+
+            return null;
         }
+        
         path = path.substring(prefix.length());
         int slash = path.lastIndexOf("/");
         int period = path.lastIndexOf(".");
@@ -785,11 +759,11 @@ public class RequestProcessor {
 
 
     /**
-     * Populate the properties of the specified ActionForm instance from
+     * <p>Populate the properties of the specified <code>ActionForm</code> instance from
      * the request parameters included with this request.  In addition,
      * request attribute <code>Globals.CANCEL_KEY</code> will be set if
      * the request was submitted with a button created by
-     * <code>CancelTag</code>.
+     * <code>CancelTag</code>.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -812,18 +786,22 @@ public class RequestProcessor {
         if (log.isDebugEnabled()) {
             log.debug(" Populating bean properties from this request");
         }
+        
         form.setServlet(this.servlet);
         form.reset(mapping, request);
+        
         if (mapping.getMultipartClass() != null) {
             request.setAttribute(Globals.MULTIPART_KEY,
                                  mapping.getMultipartClass());
         }
+        
         RequestUtils.populate(form, mapping.getPrefix(), mapping.getSuffix(),
                               request);
 
         // Set the cancellation request attribute if appropriate
         if ((request.getParameter(Constants.CANCEL_PROPERTY) != null) ||
             (request.getParameter(Constants.CANCEL_PROPERTY_X) != null)) {
+                
             request.setAttribute(Globals.CANCEL_KEY, Boolean.TRUE);
         }
 
@@ -831,10 +809,10 @@ public class RequestProcessor {
 
 
     /**
-     * General-purpose preprocessing hook that can be overridden as required
-     * by subclasses.  Return <code>true</code> if you want standard processing
+     * <p>General-purpose preprocessing hook that can be overridden as required
+     * by subclasses. Return <code>true</code> if you want standard processing
      * to continue, or <code>false</code> if the response has already been
-     * completed.  The default implementation does nothing.
+     * completed. The default implementation does nothing.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -848,10 +826,10 @@ public class RequestProcessor {
 
 
     /**
-     * If this action is protected by security roles, make sure that the
+     * <p>If this action is protected by security roles, make sure that the
      * current user possesses at least one of them.  Return <code>true</code>
      * to continue normal processing, or <code>false</code> if an appropriate
-     * response has been created and processing should terminate.
+     * response has been created and processing should terminate.</p>
      *
      * @param request The servlet request we are processing
      * @param response The servlet response we are creating
@@ -887,9 +865,11 @@ public class RequestProcessor {
             log.debug(" User '" + request.getRemoteUser() +
                       "' does not have any required role, denying access");
         }
-        response.sendError(HttpServletResponse.SC_BAD_REQUEST,
-                           getInternal().getMessage("notAuthorized",
-                                                    mapping.getPath()));
+        
+        response.sendError(
+            HttpServletResponse.SC_FORBIDDEN,
+            getInternal().getMessage("notAuthorized", mapping.getPath()));
+                                                    
         return (false);
 
     }
@@ -898,8 +878,8 @@ public class RequestProcessor {
     /**
      * <p>If this request was not cancelled, and the request's
      * {@link ActionMapping} has not disabled validation, call the
-     * <code>validate()</code> method of the specified {@link ActionForm},
-     * and forward back to the input form if there were any errors.
+     * <code>validate</code> method of the specified {@link ActionForm},
+     * and forward to the input path if there were any errors.
      * Return <code>true</code> if we should continue processing,
      * or <code>false</code> if we have already forwarded control back
      * to the input form.</p>
@@ -921,8 +901,7 @@ public class RequestProcessor {
         if (form == null) {
             return (true);
         }
-
-        // Was this request cancelled?
+                                              // Was this request cancelled?
         if (request.getAttribute(Globals.CANCEL_KEY) != null) {
             if (log.isDebugEnabled()) {
                 log.debug(" Cancelled transaction, skipping validation");
@@ -939,7 +918,7 @@ public class RequestProcessor {
         if (log.isDebugEnabled()) {
             log.debug(" Validating input form properties");
         }
-        ActionErrors errors = form.validate(mapping, request);
+        ActionMessages errors = form.validate(mapping, request);
         if ((errors == null) || errors.isEmpty()) {
             if (log.isTraceEnabled()) {
                 log.trace("  No errors detected, accepting input");
@@ -955,7 +934,7 @@ public class RequestProcessor {
             form.getMultipartRequestHandler().rollback();
         }
 
-        // Has an input form been specified for this mapping?
+        // Was an input path (or forward) specified for this mapping?
         String input = mapping.getInput();
         if (input == null) {
             if (log.isTraceEnabled()) {
@@ -984,15 +963,18 @@ public class RequestProcessor {
 
     }
 
+
     /**
-     * Do a module relative forward to specified uri using request dispatcher.
-     * Uri is relative to the current module. The real uri is compute by prefixing
-     * the module name.
-     * This method is used internally and is not part of the public API. It is
-     * advised to not use it in subclasses.
+     * <p>Do a module relative forward to specified URI using request dispatcher.
+     * URI is relative to the current module. The real URI is compute by prefixing
+     * the module name.</p>
+     * <p>This method is used internally and is not part of the public API. It is
+     * advised to not use it in subclasses. </p>
+     *
      * @param uri Module-relative URI to forward to
      * @param request Current page request
      * @param response Current page response
+     *
      * @since Struts 1.1
      */
     protected void internalModuleRelativeForward(
@@ -1005,22 +987,25 @@ public class RequestProcessor {
         uri = moduleConfig.getPrefix() + uri;
 
         // Delegate the processing of this request
-        // FIXME - exception handling?
+        // :FIXME: - exception handling?
         if (log.isDebugEnabled()) {
             log.debug(" Delegating via forward to '" + uri + "'");
         }
         doForward(uri, request, response);
     }
 
+
     /**
-     * Do a module relative include to specified uri using request dispatcher.
-     * Uri is relative to the current module. The real uri is compute by prefixing
-     * the module name.
-     * This method is used internally and is not part of the public API. It is
-     * advised to not use it in subclasses.
+     * <p>Do a module relative include to specified URI using request dispatcher.
+     * URI is relative to the current module. The real URI is compute by prefixing
+     * the module name.</p>
+     * <p>This method is used internally and is not part of the public API. It is
+     * advised to not use it in subclasses.</p>
+     *
      * @param uri Module-relative URI to include
      * @param request Current page request
      * @param response Current page response
+     *
      * @since Struts 1.1
      */
     protected void internalModuleRelativeInclude(
@@ -1040,9 +1025,11 @@ public class RequestProcessor {
         doInclude(uri, request, response);
     }
 
+
     /**
-     * Do a forward to specified uri using request dispatcher.
-     * This method is used by all internal method needing to do a forward.
+     * <p>Do a forward to specified URI using a <code>RequestDispatcher</code>.
+     * This method is used by all internal method needing to do a forward.</p>
+     *
      * @param uri Context-relative URI to forward to
      * @param request Current page request
      * @param response Current page response
@@ -1071,8 +1058,9 @@ public class RequestProcessor {
 
 
     /**
-     * Do an include of specified uri using request dispatcher.
-     * This method is used by all internal method needing to do an include
+     * <p>Do an include of specified URI using a <code>RequestDispatcher</code>.
+     * This method is used by all internal method needing to do an include.</p>
+     *
      * @param uri Context-relative URI to include
      * @param request Current page request
      * @param response Current page response
@@ -1104,22 +1092,8 @@ public class RequestProcessor {
 
 
     /**
-     * Return the debugging detail level that has been configured for our
-     * controller servlet.
-     *
-     * @deprecated Configure the logging detail level in your
-     *  underlying logging implementation
-     */
-    public int getDebug() {
-
-        return (servlet.getDebug());
-
-    }
-
-
-    /**
-     * Return the <code>MessageResources</code> instance containing our
-     * internal message strings.
+     * <p>Return the <code>MessageResources</code> instance containing our
+     * internal message strings.</p>
      */
     protected MessageResources getInternal() {
 
@@ -1129,7 +1103,8 @@ public class RequestProcessor {
 
 
     /**
-     * Return the ServletContext for the web application we are running in.
+     * <p>Return the <code>ServletContext</code> for the web application in which
+     * we are running.
      */
     protected ServletContext getServletContext() {
 
@@ -1137,13 +1112,17 @@ public class RequestProcessor {
 
     }
 
+
     /**
-     * Log the specified message to the servlet context log for this
-     * web application.
+     * <p>Log the specified message to the servlet context log for this
+     * web application.</p>
      *
      * @param message The message to be logged
+     * @deprecated Use commons-logging instead. This will be removed in a release
+     * after Struts 1.2.
      */
     protected void log(String message) {
+        // :TODO: Remove after Struts 1.2
 
         servlet.log(message);
 
@@ -1151,13 +1130,17 @@ public class RequestProcessor {
 
 
     /**
-     * Log the specified message and exception to the servlet context log
-     * for this web application.
+     * <p>Log the specified message and exception to the servlet context log
+     * for this web application.</p>
      *
      * @param message The message to be logged
      * @param exception The exception to be logged
+
+     * @deprecated Use commons-logging instead.  This will be removed in a release
+     * after Struts 1.2.
      */
     protected void log(String message, Throwable exception) {
+        // :TODO: Remove after Sruts 1.2
 
         servlet.log(message, exception);
 
