@@ -1,68 +1,25 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/config/ActionConfig.java,v 1.11 2003/05/01 16:45:33 rleland Exp $
- * $Revision: 1.11 $
- * $Date: 2003/05/01 16:45:33 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/config/ActionConfig.java,v 1.18 2004/03/14 06:23:47 sraeburn Exp $
+ * $Revision: 1.18 $
+ * $Date: 2004/03/14 06:23:47 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
-
 package org.apache.struts.config;
 
-
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -73,11 +30,9 @@ import java.util.HashMap;
  * <code>&lt;action&gt;</code> element from a Struts
  * module configuration file.</p>
  *
- * @author Craig R. McClanahan
- * @version $Revision: 1.11 $ $Date: 2003/05/01 16:45:33 $
+ * @version $Revision: 1.18 $ $Date: 2004/03/14 06:23:47 $
  * @since Struts 1.1
  */
-
 public class ActionConfig implements Serializable {
 
 
@@ -112,14 +67,6 @@ public class ActionConfig implements Serializable {
      */
     protected ModuleConfig moduleConfig = null;
 
-    /**
-     * The module configuration with which we are associated.
-     * @deprecated  {@link #getModuleConfig()}
-     */
-    public ModuleConfig getApplicationConfig() {
-        return (getModuleConfig());
-    }
-
     /**
      * The module configuration with which we are associated.
      */
@@ -127,14 +74,6 @@ public class ActionConfig implements Serializable {
         return (this.moduleConfig);
     }
 
-    /**
-     * The module configuration with which we are associated.
-     * @deprecated  {@link #setModuleConfig(ModuleConfig)}
-     */
-    public void setApplicationConfig(ModuleConfig moduleConfig) {
-       setModuleConfig(moduleConfig);
-    }
-
     /**
      * The module configuration with which we are associated.
      */
@@ -142,6 +81,7 @@ public class ActionConfig implements Serializable {
         if (configured) {
             throw new IllegalStateException("Configuration is frozen");
         }
+
         this.moduleConfig = moduleConfig;
     }
 
@@ -548,13 +488,13 @@ public class ActionConfig implements Serializable {
 
     /**
      * Indicates Action be configured as the default one for this
-     * application, when true.
+     * module, when true.
      */
     protected boolean unknown = false;
 
     /**
       * Determine whether Action is configured as the default one for this
-      * application.
+      * module.
       */
     public boolean getUnknown() {
         return (this.unknown);
@@ -562,7 +502,7 @@ public class ActionConfig implements Serializable {
 
     /**
       * @param unknown Indicates Action is configured as the default one for this
-      * application, when true.
+      * module, when true.
       */
     public void setUnknown(boolean unknown) {
         if (configured) {
@@ -654,6 +594,51 @@ public class ActionConfig implements Serializable {
 
     }
 
+    /**
+     * <p>Find and return the <code>ExceptionConfig</code> instance defining
+     * how <code>Exceptions</code> of the specified type should be handled.
+     * This is performed by checking local and then global configurations for
+     * the specified exception's class, and then looking up the superclass chain
+     * (again checking local and then global configurations). If no handler
+     * configuration can be found, return <code>null</code>.</p>
+     *
+     * <p>Introduced in <code>ActionMapping</code> in Struts 1.1, but pushed
+     * up to <code>ActionConfig</code> in Struts 1.2.0.</p>
+     *
+     * @param type Exception class for which to find a handler
+     * @since Struts 1.2.0
+     */
+    public ExceptionConfig findException(Class type) {
+
+        // Check through the entire superclass hierarchy as needed
+        ExceptionConfig config = null;
+        while (true) {
+
+            // Check for a locally defined handler
+            String name = type.getName();
+            config = findExceptionConfig(name);
+            if (config != null) {
+                return (config);
+            }
+
+            // Check for a globally defined handler
+            config = getModuleConfig().findExceptionConfig(name);
+            if (config != null) {
+                return (config);
+            }
+
+            // Loop again for our superclass (if any)
+            type = type.getSuperclass();
+            if (type == null) {
+                break;
+            }
+
+        }
+        return (null); // No handler has been configured
+
+    }
+
+
 
     /**
      * Return the forward configuration for the specified key, if any;
@@ -669,7 +654,7 @@ public class ActionConfig implements Serializable {
 
 
     /**
-     * Return the form bean configurations for this application.  If there
+     * Return all forward configurations for this module.  If there
      * are none, a zero-length array is returned.
      */
     public ForwardConfig[] findForwardConfigs() {
