@@ -1,69 +1,25 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/config/ConfigHelper.java,v 1.5 2003/05/04 22:41:13 dgraham Exp $
- * $Revision: 1.5 $
- * $Date: 2003/05/04 22:41:13 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/config/ConfigHelper.java,v 1.17 2004/03/14 06:23:47 sraeburn Exp $
+ * $Revision: 1.17 $
+ * $Date: 2004/03/14 06:23:47 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.struts.config;
 
-import java.util.Iterator;
-import java.util.Locale;
-
 import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -71,19 +27,14 @@ import javax.servlet.http.HttpSession;
 import javax.sql.DataSource;
 
 import org.apache.struts.Globals;
-import org.apache.struts.action.Action;
-import org.apache.struts.action.ActionError;
-import org.apache.struts.action.ActionErrors;
 import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionFormBean;
-import org.apache.struts.action.ActionFormBeans;
 import org.apache.struts.action.ActionForward;
-import org.apache.struts.action.ActionForwards;
 import org.apache.struts.action.ActionMapping;
-import org.apache.struts.action.ActionMappings;
 import org.apache.struts.action.ActionMessages;
 import org.apache.struts.upload.MultipartRequestWrapper;
 import org.apache.struts.util.MessageResources;
+import org.apache.struts.util.RequestUtils;
 
 /**
  * NOTE: THIS CLASS IS UNDER ACTIVE DEVELOPMENT.
@@ -108,10 +59,8 @@ import org.apache.struts.util.MessageResources;
  * from under the context and key used by the Struts
  * ActionServlet when the resources are created.
  *
- * @since 1.1
- * @author Ted Husted
- * @author Luis Arias <luis@elysia.com>
- * @version $Revision: 1.5 $ $Date: 2003/05/04 22:41:13 $
+ * @since Struts 1.1
+ * @version $Revision: 1.17 $ $Date: 2004/03/14 06:23:47 $
  */
 public class ConfigHelper implements ConfigHelperInterface {
 
@@ -202,15 +151,30 @@ public class ConfigHelper implements ConfigHelperInterface {
         ServletContext application,
         HttpServletRequest request,
         HttpServletResponse response) {
+        
         setApplication(application);
         setRequest(request);
         setResponse(response);
     }
+    
+    public ConfigHelper() {
+        super();
+    }
+
+    public ConfigHelper(
+        ServletContext application,
+        HttpServletRequest request,
+        HttpServletResponse response) {
+            
+        super();
+        this.setResources(application, request, response);
+    }
+    
 
     // ------------------------------------------------ Application Context
 
     /**
-     * The strong>default</strong>
+     * The <strong>default</strong>
      * configured data source (which must implement
      * <code>javax.sql.DataSource</code>),
      * if one is configured for this application.
@@ -231,45 +195,6 @@ public class ConfigHelper implements ConfigHelperInterface {
 
     }
 
-    /**
-     * The <code>org.apache.struts.action.ActionFormBeans</code> collection
-     * for this application.
-     */
-    public ActionFormBeans getActionFormBeans() {
-
-        if (this.application == null) {
-            return null;
-        }
-        return (ActionFormBeans) this.application.getAttribute(Globals.FORM_BEANS_KEY);
-
-    }
-
-    /**
-     * The <code>org.apache.struts.action.ActionForwards</code> collection
-     * for this application.
-     */
-    public ActionForwards getActionForwards() {
-
-        if (this.application == null) {
-            return null;
-        }
-        return (ActionForwards) this.application.getAttribute(Globals.FORWARDS_KEY);
-
-    }
-
-    /**
-     * The context attributes key under which our
-     * <code>org.apache.struts.action.ActionMappings</code> collection
-     * is normally stored, unless overridden when initializing our
-     * ActionServlet.
-     */
-    public ActionMappings getActionMappings() {
-        if (this.application == null) {
-            return null;
-        }
-        return (ActionMappings) this.application.getAttribute(Globals.MAPPINGS_KEY);
-    }
-
     /**
      * The application resources for this application.
      */
@@ -298,27 +223,6 @@ public class ConfigHelper implements ConfigHelperInterface {
 
     // ---------------------------------------------------- Session Context
 
-    /**
-     * The <code>java.util.Locale</code> for the user, if any.
-     * If a default locale object is not in the user's session,
-     * the system default locale is returned.
-     * If used, the user locale is typically set during login
-     * processing under the key <code>Globals.LOCALE_KEY</code>.
-     */
-    public Locale getLocale() {
-        Locale locale = null;
-
-        if (session != null) {
-            locale = (Locale) session.getAttribute(Globals.LOCALE_KEY);
-        }
-
-        if ((locale == null) && (request != null)) {
-            locale = request.getLocale();
-        }
-
-        return locale;
-    }
-
     /**
      * The transaction token stored in this session, if it is used.
      */
@@ -333,19 +237,6 @@ public class ConfigHelper implements ConfigHelperInterface {
 
     // ---------------------------------------------------- Request Context
 
-    /**
-     * The <code>org.apache.struts.action.ActionErrors</code> object,
-     * for this request.
-     */
-    public ActionErrors getActionErrors() {
-
-        if (this.request == null) {
-            return null;
-        }
-        return (ActionErrors) this.request.getAttribute(Globals.ERROR_KEY);
-
-    }
-
     /**
      * The runtime JspException that may be been thrown by a Struts tag
      * extension, or compatible presentation extension, and placed
@@ -402,7 +293,7 @@ public class ConfigHelper implements ConfigHelperInterface {
         }
 
         // Return the requested message presence indicator
-        return (resources.isPresent(getLocale(), key));
+        return resources.isPresent(RequestUtils.getUserLocale(request, null), key);
 
     }
 
@@ -442,13 +333,7 @@ public class ConfigHelper implements ConfigHelperInterface {
      * @param name Logical name of the requested form bean definition
      */
     public ActionFormBean getFormBean(String name) {
-
-        ActionFormBeans formBeans = getActionFormBeans();
-
-        if (formBeans == null)
-            return null;
-        return formBeans.findFormBean(name);
-
+        return null;
     }
 
     /**
@@ -458,13 +343,7 @@ public class ConfigHelper implements ConfigHelperInterface {
      * @param name Logical name of the requested forwarding
      */
     public ActionForward getActionForward(String name) {
-
-        ActionForwards forwards = getActionForwards();
-
-        if (forwards == null)
-            return null;
-        return forwards.findForward(name);
-
+        return null;
     }
 
     /**
@@ -474,13 +353,7 @@ public class ConfigHelper implements ConfigHelperInterface {
      * @param path Request path for which a mapping is requested
      */
     public ActionMapping getActionMapping(String path) {
-
-        ActionMappings mappings = getActionMappings();
-
-        if (mappings == null)
-            return null;
-        return mappings.findMapping(path);
-
+        return null;
     }
 
     /**
@@ -581,21 +454,7 @@ public class ConfigHelper implements ConfigHelperInterface {
 
         if (request == null)
             return null;
-
-        StringBuffer result = new StringBuffer();
-        result.append(request.getScheme());
-        result.append("://");
-        result.append(request.getServerName());
-        if ("http".equals(request.getScheme()) && (80 == request.getServerPort())) {
-            ;
-        } else if ("https".equals(request.getScheme()) && (443 == request.getServerPort())) {
-            ;
-        } else {
-            result.append(":");
-            result.append(request.getServerPort());
-        }
-        result.append(request.getRequestURI());
-
+        StringBuffer result = RequestUtils.requestToServerUriStringBuffer(request);
         return result.toString();
     }
 
@@ -607,18 +466,7 @@ public class ConfigHelper implements ConfigHelperInterface {
         if (request == null)
             return null;
 
-        StringBuffer result = new StringBuffer();
-        result.append(request.getScheme());
-        result.append("://");
-        result.append(request.getServerName());
-        if ("http".equals(request.getScheme()) && (80 == request.getServerPort())) {
-            ;
-        } else if ("https".equals(request.getScheme()) && (443 == request.getServerPort())) {
-            ;
-        } else {
-            result.append(":");
-            result.append(request.getServerPort());
-        }
+        StringBuffer result = RequestUtils.requestToServerStringBuffer(request);
         String path = null;
         if (forward == null)
             path = request.getRequestURI();
@@ -661,7 +509,8 @@ public class ConfigHelper implements ConfigHelperInterface {
         MessageResources resources = getMessageResources();
         if (resources == null)
             return null;
-        return resources.getMessage(getLocale(), key);
+
+        return resources.getMessage(RequestUtils.getUserLocale(request, null), key);
 
     }
 
@@ -680,9 +529,14 @@ public class ConfigHelper implements ConfigHelperInterface {
 
         // Return the requested message
         if (args == null)
-            return (resources.getMessage(getLocale(), key));
+            return resources.getMessage(
+                RequestUtils.getUserLocale(request, null),
+                key);
         else
-            return (resources.getMessage(getLocale(), key, args));
+            return resources.getMessage(
+                RequestUtils.getUserLocale(request, null),
+                key,
+                args);
 
     }
 
@@ -693,144 +547,9 @@ public class ConfigHelper implements ConfigHelperInterface {
      * @param path Name given to local or global forward.
      */
     public String getAction(String path) {
-
         return getEncodeURL(getActionMappingURL(path));
-
     }
 
-    /**
-     * Return the number of error messages.
-     */
-    public int getErrorSize() {
-
-        ActionErrors actionErrors = getActionErrors();
-
-        if (actionErrors == null)
-            return 0;
-
-        return actionErrors.size();
-    }
-
-    /**
-     * Return true if there are no errors queued
-     */
-    public boolean getErrorsEmpty() {
-
-        ActionErrors actionErrors = getActionErrors();
-
-        if (actionErrors == null)
-            return false;
-
-        return actionErrors.isEmpty();
-    }
-
-    /**
-     * Return the error messages
-     */
-    public Iterator getErrors() {
-
-        ActionErrors actionErrors = getActionErrors();
-
-        if (actionErrors == null)
-            return null;
-
-        return actionErrors.get();
-    }
-
-    /**
-     * Return an ActionError for a property
-     *
-     * @param property Property name
-     */
-    public Iterator getErrors(String property) {
-
-        ActionErrors actionErrors = getActionErrors();
-
-        if (actionErrors == null)
-            return null;
-
-        return actionErrors.get(property);
-    }
-
-    /**
-     * Return the number of error messages.
-     *
-     * @param property Property name
-     */
-    public int getErrorSize(String property) {
-
-        ActionErrors actionErrors = getActionErrors();
-
-        if (actionErrors == null)
-            return 0;
-
-        return actionErrors.size(property);
-    }
-
-    /**
-     * Returns the errors.header, any errors, and the errors.footer.
-     *
-     * @param property Property name
-     */
-    public String getErrorOutput(String property) {
-
-        ActionErrors errors = getActionErrors();
-
-        if ((errors == null) || (errors.isEmpty())) {
-            return null;
-        }
-
-        // Check for presence of header and footer message keys
-        boolean headerPresent = isMessage("errors.header");
-        boolean footerPresent = isMessage("errors.footer");
-
-        // Render the error messages appropriately
-        StringBuffer results = new StringBuffer();
-        String message = null;
-        if (headerPresent)
-            message = getMessage("errors.header");
-        Iterator reports = null;
-
-        if (property == null)
-            reports = errors.get();
-        else
-            reports = errors.get(property);
-
-        // Render header if this is a global tag or there is an error for this property
-        boolean propertyMsgPresent = reports.hasNext();
-        if ((message != null) && (property == null) || propertyMsgPresent) {
-            results.append(message);
-            results.append("\r\n");
-        }
-
-        while (reports.hasNext()) {
-            ActionError report = (ActionError) reports.next();
-            message = getMessage(report.getKey(), report.getValues());
-            if (message != null) {
-                results.append(message);
-                results.append("\r\n");
-            }
-        }
-        message = null;
-        if (footerPresent)
-            message = getMessage("errors.footer");
-
-        if ((message != null) && (property == null) || propertyMsgPresent) {
-            results.append(message);
-            results.append("\r\n");
-        }
-
-        // return result
-        return results.toString();
-
-    }
-
-    /**
-     * Wrapper for getErrorMarkup(null)
-     */
-    public String getErrorOutput() {
-        return getErrorOutput(null);
-    }
 
     // --------------------------------------------- Presentation Wrappers
 
@@ -871,69 +590,9 @@ public class ConfigHelper implements ConfigHelperInterface {
         return getAction(path);
     }
 
-    /**
-     * Alias for getErrorSize()
-     */
-    public int errorSize() {
-        return getErrorSize();
-    }
 
-    /**
-     * Wrapper for getErrorEmpty()
-     */
-    public boolean errorsEmpty() {
-        return getErrorsEmpty();
-    }
 
-    /**
-     * Wrapper for getErrors()
-     */
-    public Iterator errors() {
-        return errors();
-    }
 
-    /**
-     * Wrapper for getErrors(String)
-     */
-    public Iterator errors(String property) {
-        return getErrors(property);
-    }
 
-    /**
-     * Wrapper for getErrorSize(String)
-     *
-     * @param property Property name
-     */
-    public int errorSize(String property) {
-        return getErrorSize(property);
-    }
-
-    /**
-     * Wrapper for getErrorMarkup(String)
-     */
-    public String errorOutput(String property) {
-        return getErrorOutput(property);
-    }
-
-    /**
-     * Wrapper for getErrorMarkup()
-     */
-    public String errorOutput() {
-        return getErrorOutput();
-    }
-
-    // ------------------------------------------------------- Constructors
-
-    public ConfigHelper() {
-        super();
-    }
-
-    public ConfigHelper(
-        ServletContext application,
-        HttpServletRequest request,
-        HttpServletResponse response) {
-        super();
-        setResources(application, request, response);
-    }
 
 }
