@@ -1,72 +1,32 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/config/impl/ModuleConfigImpl.java,v 1.5 2003/02/06 03:32:10 dgraham Exp $
- * $Revision: 1.5 $
- * $Date: 2003/02/06 03:32:10 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/config/impl/ModuleConfigImpl.java,v 1.14 2004/04/14 23:46:15 husted Exp $
+ * $Revision: 1.14 $
+ * $Date: 2004/04/14 23:46:15 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
-
 package org.apache.struts.config.impl;
 
 import java.io.Serializable;
 import java.util.ArrayList;
+import java.util.List;
 import java.util.HashMap;
 
 import org.apache.struts.config.ActionConfig;
+import org.apache.struts.config.ActionConfigMatcher;
 import org.apache.struts.config.ControllerConfig;
 import org.apache.struts.config.DataSourceConfig;
 import org.apache.struts.config.ExceptionConfig;
@@ -85,12 +45,11 @@ import org.apache.struts.config.PlugInConfig;
  * string) is selected, which is elegantly backwards compatible with the
  * previous Struts behavior that only supported one module.</p>
  *
- *
- * @author Craig R. McClanahan
- * @version $Revision: 1.5 $ $Date: 2003/02/06 03:32:10 $
+ * @version $Revision: 1.14 $ $Date: 2004/04/14 23:46:15 $
  * @since Struts 1.1
  */
 public class ModuleConfigImpl implements Serializable, ModuleConfig {
+    
     /**
      * Construct an ModuleConfigImpl object according to the specified
      * parameter values.
@@ -101,7 +60,10 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         super();
         this.prefix = prefix;
         this.actionConfigs = new HashMap();
-        this.actionMappingClass =  "org.apache.struts.action.ActionMapping";
+        this.actionConfigList = new ArrayList();
+        this.actionFormBeanClass = "org.apache.struts.action.ActionFormBean";
+        this.actionMappingClass = "org.apache.struts.action.ActionMapping";
+        this.actionForwardClass = "org.apache.struts.action.ActionForward";
         this.configured = false;
         this.controllerConfig = null;
         this.dataSources = new HashMap();
@@ -112,32 +74,6 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         this.plugIns = new ArrayList();
     }
 
-    /**
-     * Only used while we are deprecating ApplicationConfig.
-     * performs a shallow copy to ensure that any operations
-     * performed on an ApplicationConfig object is
-     * performed on the same underlying
-     * ModuleConfigImpl sub objects
-     * @param moduleConfig
-     * @deprecated   Only used while we are deprecating ApplicationConfig to insure maximum compatability.
-     */
-    public ModuleConfigImpl(ModuleConfigImpl moduleConfig) {
-
-        super();
-        this.actionConfigs = moduleConfig.actionConfigs;
-        this.actionMappingClass = moduleConfig.actionMappingClass;
-        this.configured = moduleConfig.configured;
-        this.controllerConfig = moduleConfig.controllerConfig;
-        this.dataSources = moduleConfig.dataSources;
-        this.exceptions = moduleConfig.exceptions;
-        this.formBeans = moduleConfig.formBeans;
-        this.forwards = moduleConfig.forwards;
-        this.messageResources = moduleConfig.messageResources;
-        this.plugIns = moduleConfig.plugIns;
-        this.prefix = moduleConfig.prefix;
-
-    }
-
 
     // --------------------------------------------------------- Public Methods
 
@@ -194,20 +130,37 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         this.prefix = prefix;
     }
 
+    /**
+     * The default class name to be used when creating action form bean
+     * instances.
+     */
+    public String getActionFormBeanClass() {
+        return this.actionFormBeanClass;
+    }
 
     /**
-     * The default class name to be used when creating action mapping
+     * The default class name to be used when creating action form bean
      * instances.
+     *
+     * @param actionFormBeanClass default class name to be used when creating 
+     *                            action form bean instances.
+     */
+    public void setActionFormBeanClass(String actionFormBeanClass) {
+        this.actionFormBeanClass = actionFormBeanClass;
+    }
+
+    /**
+     * The default class name to be used when creating action mapping instances.
      */
     public String getActionMappingClass() {
         return this.actionMappingClass;
     }
 
     /**
-     * The default class name to be used when creating action mapping
-     * instances.
-     * @param actionMappingClass  default class name to be used when creating action mapping
-     * instances.
+     * The default class name to be used when creating action mapping instances.
+     *
+     * @param actionMappingClass default class name to be used when creating 
+     *                           action mapping instances.
      */
     public void setActionMappingClass(String actionMappingClass) {
         this.actionMappingClass = actionMappingClass;
@@ -229,6 +182,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         }
         config.setModuleConfig(this);
         actionConfigs.put(config.getPath(), config);
+        actionConfigList.add(config);
 
     }
 
@@ -282,11 +236,27 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         if (configured) {
             throw new IllegalStateException("Configuration is frozen");
         }
-        config.setModuleConfig(this);
         formBeans.put(config.getName(), config);
 
     }
 
+    /**
+     * The default class name to be used when creating action forward instances.
+     */
+    public String getActionForwardClass() {
+        return this.actionForwardClass;
+    }
+
+    /**
+     * The default class name to be used when creating action forward instances.
+     *
+     * @param actionForwardClass default class name to be used when creating
+     *                           action forward instances.
+     */
+    public void setActionForwardClass(String actionForwardClass) {
+        this.actionForwardClass= actionForwardClass;
+    }
+
     /**
      * Add a new <code>ForwardConfig</code> instance to the set of global
      * forwards associated with this module.
@@ -339,14 +309,23 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
     }
 
     /**
-     * Return the action configuration for the specified path, if any;
+     * Return the action configuration for the specified path, first looking
+     * a direct match, then if none found, a wildcard pattern match;
      * otherwise return <code>null</code>.
      *
      * @param path Path of the action configuration to return
      */
     public ActionConfig findActionConfig(String path) {
 
-        return ((ActionConfig) actionConfigs.get(path));
+        ActionConfig config = (ActionConfig) actionConfigs.get(path);
+        
+        // If a direct match cannot be found, try to match action configs 
+        // containing wildcard patterns
+        if (config == null) {
+            config = matcher.match(path);
+        }
+        
+        return config;
 
     }
 
@@ -356,8 +335,8 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
      */
     public ActionConfig[] findActionConfigs() {
 
-        ActionConfig results[] = new ActionConfig[actionConfigs.size()];
-        return ((ActionConfig[]) actionConfigs.values().toArray(results));
+        ActionConfig results[] = new ActionConfig[actionConfigList.size()];
+        return ((ActionConfig[]) actionConfigList.toArray(results));
 
     }
 
@@ -502,6 +481,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         for (int i = 0; i < aconfigs.length; i++) {
             aconfigs[i].freeze();
         }
+        matcher = new ActionConfigMatcher(aconfigs);
 
         getControllerConfig().freeze();
 
@@ -534,7 +514,6 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         for (int i = 0; i < piconfigs.length; i++) {
             piconfigs[i].freeze();
         }
-
     }
 
     /**
@@ -542,7 +521,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
      *
      * @param config ActionConfig instance to be removed
      *
-     * @exception java.lang.IllegalStateException if this module configuration
+     * @exception IllegalStateException if this module configuration
      *  has been frozen
      */
     public void removeActionConfig(ActionConfig config) {
@@ -552,6 +531,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         }
         config.setModuleConfig(null);
         actionConfigs.remove(config.getPath());
+        actionConfigList.remove(config);
 
     }
 
@@ -560,7 +540,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
      *
      * @param config ActionConfig instance to be removed
      *
-     * @exception java.lang.IllegalStateException if this module configuration
+     * @exception IllegalStateException if this module configuration
      *  has been frozen
      */
     public void removeExceptionConfig(ExceptionConfig config) {
@@ -577,7 +557,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
      *
      * @param config DataSourceConfig instance to be removed
      *
-     * @exception java.lang.IllegalStateException if this module configuration
+     * @exception IllegalStateException if this module configuration
      *  has been frozen
      */
     public void removeDataSourceConfig(DataSourceConfig config) {
@@ -594,7 +574,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
      *
      * @param config FormBeanConfig instance to be removed
      *
-     * @exception java.lang.IllegalStateException if this module configuration
+     * @exception IllegalStateException if this module configuration
      *  has been frozen
      */
     public void removeFormBeanConfig(FormBeanConfig config) {
@@ -602,7 +582,6 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
         if (configured) {
             throw new IllegalStateException("Configuration is frozen");
         }
-        config.setModuleConfig(null);
         formBeans.remove(config.getName());
 
     }
@@ -612,7 +591,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
      *
      * @param config ForwardConfig instance to be removed
      *
-     * @exception java.lang.IllegalStateException if this module configuration
+     * @exception IllegalStateException if this module configuration
      *  has been frozen
      */
     public void removeForwardConfig(ForwardConfig config) {
@@ -629,7 +608,7 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
      *
      * @param config MessageResourcesConfig instance to be removed
      *
-     * @exception java.lang.IllegalStateException if this module configuration
+     * @exception IllegalStateException if this module configuration
      *  has been frozen
      */
     public void removeMessageResourcesConfig(MessageResourcesConfig config) {
@@ -641,12 +620,6 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
 
     }
 
-
-    // -------------------------------------------------------- Package Methods
-
-
-    // ------------------------------------------------------ Protected Methods
-
     // ----------------------------------------------------- Instance Variables
     // Instance Variables at end to make comparing Interface and implementation easier.
 
@@ -657,6 +630,12 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
      */
     protected HashMap actionConfigs = null;
     
+    /**
+     * The set of action configurations for this module, if any,
+     * listed in the order in which they are added.
+     */
+    protected List actionConfigList = null; 
+    
     /**
      * The set of JDBC data source configurations for this
      * module, if any, keyed by the <code>key</code> property.
@@ -714,9 +693,24 @@ public class ModuleConfigImpl implements Serializable, ModuleConfig {
     protected String prefix = null;
     
     /**
-     * The default class name to be used when creating action mapping
+     * The default class name to be used when creating action form bean
      * instances.
      */
+    protected String actionFormBeanClass = "org.apache.struts.action.ActionFormBean";
+    
+    /**
+     * The default class name to be used when creating action mapping instances.
+     */
     protected String actionMappingClass = "org.apache.struts.action.ActionMapping";
+    
+    /**
+     * The default class name to be used when creating action forward instances.
+     */
+    protected String actionForwardClass = "org.apache.struts.action.ActionForward";
+    
+    /**
+     * Matches action config paths against compiled wildcard patterns
+     */
+    protected ActionConfigMatcher matcher = null;
 
 }
