@@ -1,62 +1,21 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/taglib/html/BaseHandlerTag.java,v 1.25 2003/05/18 18:57:13 dgraham Exp $
- * $Revision: 1.25 $
- * $Date: 2003/05/18 18:57:13 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/taglib/html/BaseHandlerTag.java,v 1.36 2004/03/14 06:23:46 sraeburn Exp $
+ * $Revision: 1.36 $
+ * $Date: 2004/03/14 06:23:46 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.struts.taglib.html;
@@ -66,13 +25,13 @@ import java.lang.reflect.Method;
 import java.util.Locale;
 
 import javax.servlet.jsp.JspException;
-import javax.servlet.jsp.PageContext;
 import javax.servlet.jsp.tagext.BodyTagSupport;
 
 import org.apache.commons.beanutils.BeanUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.struts.Globals;
+import org.apache.struts.taglib.TagUtils;
 import org.apache.struts.taglib.logic.IterateTag;
 import org.apache.struts.util.MessageResources;
 import org.apache.struts.util.RequestUtils;
@@ -83,11 +42,8 @@ import org.apache.struts.util.RequestUtils;
  * the doStartTag() or doEndTag() methods. Subclasses should provide
  * appropriate implementations of these.
  *
- * @author Don Clasen
- * @author James Turner
- * @version $Revision: 1.25 $ $Date: 2003/05/18 18:57:13 $
+ * @version $Revision: 1.36 $ $Date: 2004/03/14 06:23:46 $
  */
-
 public abstract class BaseHandlerTag extends BodyTagSupport {
 
     /**
@@ -99,6 +55,7 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
 
     /**
      * The default Locale for our server.
+     * @deprecated Use Locale.getDefault() directly.
      */
     protected static final Locale defaultLocale = Locale.getDefault();
 
@@ -119,8 +76,8 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
     //  Indexing ability for Iterate
 
     /** Whether to created indexed names for fields
-      * @since Struts 1.1
-      */
+     * @since Struts 1.1
+     */
     protected boolean indexed = false;
 
     //  Mouse Events
@@ -237,15 +194,15 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
     //  Indexing ability for Iterate [since Struts 1.1]
 
     /** Sets the indexed value.
-      * @since Struts 1.1
-      */
+     * @since Struts 1.1
+     */
     public void setIndexed(boolean indexed) {
         this.indexed = indexed;
     }
 
     /** Returns the indexed value.
-      * @since Struts 1.1
-      */
+     * @since Struts 1.1
+     */
     public boolean getIndexed() {
         return (this.indexed);
     }
@@ -566,15 +523,20 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
 
         if (literal != null) {
             if (key != null) {
-                JspException e = new JspException(messages.getMessage("common.both"));
-                RequestUtils.saveException(pageContext, e);
+                JspException e =
+                    new JspException(messages.getMessage("common.both"));
+                TagUtils.getInstance().saveException(pageContext, e);
                 throw e;
             } else {
                 return (literal);
             }
         } else {
             if (key != null) {
-                return (RequestUtils.message(pageContext, getBundle(), getLocale(), key));
+                return TagUtils.getInstance().message(
+                    pageContext,
+                    getBundle(),
+                    getLocale(),
+                    key);
             } else {
                 return null;
             }
@@ -589,50 +551,59 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
     private boolean triedJstlInit = false;
     private boolean triedJstlSuccess = false;
 
-    private Integer getJstlLoopIndex () {
-	if (!triedJstlInit) {
-	    triedJstlInit = true;
-	    try {
-		loopTagSupportClass = 
-		    RequestUtils.applicationClass("javax.servlet.jsp.jstl.core.LoopTagSupport");
-		loopTagSupportGetStatus = 
-		    loopTagSupportClass.getDeclaredMethod("getLoopStatus", null);
-		loopTagStatusClass =
-		    RequestUtils.applicationClass("javax.servlet.jsp.jstl.core.LoopTagStatus");
-		loopTagStatusGetIndex = 
-		    loopTagStatusClass.getDeclaredMethod("getIndex", null);
-		triedJstlSuccess = true;
-	    }
-	    // These just mean that JSTL isn't loaded, so ignore
-	    catch (ClassNotFoundException ex) {}
-	    catch (NoSuchMethodException ex) {}
-	}
-	if (triedJstlSuccess) {
-	    try {
-		Object loopTag = findAncestorWithClass(this, loopTagSupportClass);
-		if (loopTag == null)  {
-		    return null;
-		}
-		Object status = loopTagSupportGetStatus.invoke(loopTag, null);
-		return (Integer) loopTagStatusGetIndex.invoke(status, null);
-	    } 
-	    catch (IllegalAccessException ex) {
-		log.error(ex.getMessage(), ex);
-	    }
-	    catch (IllegalArgumentException ex) {
-		log.error(ex.getMessage(), ex);
-	    }
-	    catch (InvocationTargetException ex) {
-		log.error(ex.getMessage(), ex);
-	    }
-	    catch (NullPointerException ex) {
-		log.error(ex.getMessage(), ex);
-	    }
-	    catch (ExceptionInInitializerError ex) {
-		log.error(ex.getMessage(), ex);
-	    }
-	}
-	return null;
+    private Integer getJstlLoopIndex() {
+        if (!triedJstlInit) {
+            triedJstlInit = true;
+            try {
+                loopTagSupportClass =
+                    RequestUtils.applicationClass(
+                        "javax.servlet.jsp.jstl.core.LoopTagSupport");
+
+                loopTagSupportGetStatus =
+                    loopTagSupportClass.getDeclaredMethod("getLoopStatus", null);
+
+                loopTagStatusClass =
+                    RequestUtils.applicationClass(
+                        "javax.servlet.jsp.jstl.core.LoopTagStatus");
+
+                loopTagStatusGetIndex =
+                    loopTagStatusClass.getDeclaredMethod("getIndex", null);
+
+                triedJstlSuccess = true;
+
+            } catch (ClassNotFoundException ex) {
+                // These just mean that JSTL isn't loaded, so ignore
+            } catch (NoSuchMethodException ex) {
+            }
+        }
+
+        if (triedJstlSuccess) {
+            try {
+                Object loopTag = findAncestorWithClass(this, loopTagSupportClass);
+                if (loopTag == null) {
+                    return null;
+                }
+
+                Object status = loopTagSupportGetStatus.invoke(loopTag, null);
+                return (Integer) loopTagStatusGetIndex.invoke(status, null);
+
+            } catch (IllegalAccessException ex) {
+                log.error(ex.getMessage(), ex);
+
+            } catch (IllegalArgumentException ex) {
+                log.error(ex.getMessage(), ex);
+
+            } catch (InvocationTargetException ex) {
+                log.error(ex.getMessage(), ex);
+
+            } catch (NullPointerException ex) {
+                log.error(ex.getMessage(), ex);
+
+            } catch (ExceptionInInitializerError ex) {
+                log.error(ex.getMessage(), ex);
+            }
+        }
+        return null;
     }
 
     /**
@@ -641,36 +612,46 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
      *  @param handlers The StringBuffer that output will be appended to.
      *  @exception JspException if 'indexed' tag used outside of iterate tag.
      */
-    protected void prepareIndex(StringBuffer handlers, String name) throws JspException {
-	int index = 0;
-	boolean found = false;
+    protected void prepareIndex(StringBuffer handlers, String name)
+        throws JspException {
+        int index = 0;
+        boolean found = false;
 
         // look for outer iterate tag
-        IterateTag iterateTag = (IterateTag) findAncestorWithClass(this, IterateTag.class);
-	// Look for JSTL loops
-	if (iterateTag == null) {
-	    Integer i = getJstlLoopIndex();
-	    if (i != null) {
-		index = i.intValue();
-		found = true;
-	    }
-	} else {
-	    index = iterateTag.getIndex();
-	    found = true;
-	}
+        IterateTag iterateTag =
+            (IterateTag) findAncestorWithClass(this, IterateTag.class);
+
+        // Look for JSTL loops
+        if (iterateTag == null) {
+            Integer i = getJstlLoopIndex();
+            if (i != null) {
+                index = i.intValue();
+                found = true;
+            }
+
+        } else {
+            index = iterateTag.getIndex();
+            found = true;
+        }
+
         if (!found) {
             // this tag should only be nested in iteratetag, if it's not, throw exception
-            JspException e = new JspException(messages.getMessage("indexed.noEnclosingIterate"));
-            RequestUtils.saveException(pageContext, e);
+            JspException e =
+                new JspException(messages.getMessage("indexed.noEnclosingIterate"));
+            TagUtils.getInstance().saveException(pageContext, e);
             throw e;
         }
-        if (name != null)
+
+        if (name != null) {
             handlers.append(name);
+        }
+
         handlers.append("[");
         handlers.append(index);
         handlers.append("]");
-        if (name != null)
+        if (name != null) {
             handlers.append(".");
+        }
     }
 
     /**
@@ -681,28 +662,28 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
     protected String prepareStyles() throws JspException {
         String value = null;
         StringBuffer styles = new StringBuffer();
-        if (style != null) {
+        if (getStyle() != null) {
             styles.append(" style=\"");
             styles.append(getStyle());
             styles.append("\"");
         }
-        if (styleClass != null) {
+        if (getStyleClass() != null) {
             styles.append(" class=\"");
             styles.append(getStyleClass());
             styles.append("\"");
         }
-        if (styleId != null) {
+        if (getStyleId() != null) {
             styles.append(" id=\"");
             styles.append(getStyleId());
             styles.append("\"");
         }
-        value = message(title, titleKey);
+        value = message(this.getTitle(), this.getTitleKey());
         if (value != null) {
             styles.append(" title=\"");
             styles.append(value);
             styles.append("\"");
         }
-        value = message(alt, altKey);
+        value = message(this.getAlt(), this.getAltKey());
         if (value != null) {
             styles.append(" alt=\"");
             styles.append(value);
@@ -730,43 +711,43 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
      * @param handlers The StringBuffer that output will be appended to.
      */
     protected void prepareMouseEvents(StringBuffer handlers) {
-        if (onclick != null) {
+        if (getOnclick() != null) {
             handlers.append(" onclick=\"");
             handlers.append(getOnclick());
             handlers.append("\"");
         }
 
-        if (ondblclick != null) {
+        if (getOndblclick() != null) {
             handlers.append(" ondblclick=\"");
             handlers.append(getOndblclick());
             handlers.append("\"");
         }
 
-        if (onmouseover != null) {
+        if (getOnmouseover() != null) {
             handlers.append(" onmouseover=\"");
             handlers.append(getOnmouseover());
             handlers.append("\"");
         }
 
-        if (onmouseout != null) {
+        if (getOnmouseout() != null) {
             handlers.append(" onmouseout=\"");
             handlers.append(getOnmouseout());
             handlers.append("\"");
         }
 
-        if (onmousemove != null) {
+        if (getOnmousemove() != null) {
             handlers.append(" onmousemove=\"");
             handlers.append(getOnmousemove());
             handlers.append("\"");
         }
 
-        if (onmousedown != null) {
+        if (getOnmousedown() != null) {
             handlers.append(" onmousedown=\"");
             handlers.append(getOnmousedown());
             handlers.append("\"");
         }
 
-        if (onmouseup != null) {
+        if (getOnmouseup() != null) {
             handlers.append(" onmouseup=\"");
             handlers.append(getOnmouseup());
             handlers.append("\"");
@@ -780,19 +761,19 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
      */
     protected void prepareKeyEvents(StringBuffer handlers) {
 
-        if (onkeydown != null) {
+        if (getOnkeydown() != null) {
             handlers.append(" onkeydown=\"");
             handlers.append(getOnkeydown());
             handlers.append("\"");
         }
 
-        if (onkeyup != null) {
+        if (getOnkeyup() != null) {
             handlers.append(" onkeyup=\"");
             handlers.append(getOnkeyup());
             handlers.append("\"");
         }
 
-        if (onkeypress != null) {
+        if (getOnkeypress() != null) {
             handlers.append(" onkeypress=\"");
             handlers.append(getOnkeypress());
             handlers.append("\"");
@@ -806,13 +787,13 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
      */
     protected void prepareTextEvents(StringBuffer handlers) {
 
-        if (onselect != null) {
+        if (getOnselect() != null) {
             handlers.append(" onselect=\"");
             handlers.append(getOnselect());
             handlers.append("\"");
         }
 
-        if (onchange != null) {
+        if (getOnchange() != null) {
             handlers.append(" onchange=\"");
             handlers.append(getOnchange());
             handlers.append("\"");
@@ -826,23 +807,23 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
      */
     protected void prepareFocusEvents(StringBuffer handlers) {
 
-        if (onblur != null) {
+        if (getOnblur() != null) {
             handlers.append(" onblur=\"");
             handlers.append(getOnblur());
             handlers.append("\"");
         }
 
-        if (onfocus != null) {
+        if (getOnfocus() != null) {
             handlers.append(" onfocus=\"");
             handlers.append(getOnfocus());
             handlers.append("\"");
         }
 
-        if (disabled) {
+        if (getDisabled()) {
             handlers.append(" disabled=\"disabled\"");
         }
 
-        if (readonly) {
+        if (getReadonly()) {
             handlers.append(" readonly=\"readonly\"");
         }
 
@@ -856,14 +837,7 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
      * @since Struts 1.1
      */
     protected boolean isXhtml() {
-        String xhtml =
-            (String) this.pageContext.getAttribute(Globals.XHTML_KEY, PageContext.PAGE_SCOPE);
-        
-        if ("true".equalsIgnoreCase(xhtml)) {
-            return true;
-        } else {
-            return false;
-        }
+        return TagUtils.getInstance().isXhtml(this.pageContext);
     }
 
     /**
@@ -873,11 +847,7 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
      * @since Struts 1.1
      */
     protected String getElementClose() {
-        if (this.isXhtml()) {
-            return " />";
-        } else {
-            return ">";
-        }
+        return this.isXhtml() ? " />" : ">";
     }
 
     /**
@@ -892,8 +862,8 @@ public abstract class BaseHandlerTag extends BodyTagSupport {
      */
     protected String lookupProperty(String beanName, String property)
         throws JspException {
-            
-        Object bean = RequestUtils.lookup(this.pageContext, beanName, null);
+
+        Object bean = TagUtils.getInstance().lookup(this.pageContext, beanName, null);
         if (bean == null) {
             throw new JspException(messages.getMessage("getter.bean", beanName));
         }
