@@ -1,62 +1,21 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/taglib/html/FormTag.java,v 1.48 2003/05/17 01:56:51 dgraham Exp $
- * $Revision: 1.48 $
- * $Date: 2003/05/17 01:56:51 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/taglib/html/FormTag.java,v 1.61 2004/07/22 01:11:42 niallp Exp $
+ * $Revision: 1.61 $
+ * $Date: 2004/07/22 01:11:42 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.struts.taglib.html;
@@ -77,19 +36,15 @@ import org.apache.struts.action.ActionMapping;
 import org.apache.struts.action.ActionServlet;
 import org.apache.struts.config.FormBeanConfig;
 import org.apache.struts.config.ModuleConfig;
+import org.apache.struts.taglib.TagUtils;
 import org.apache.struts.util.MessageResources;
 import org.apache.struts.util.RequestUtils;
-import org.apache.struts.util.ResponseUtils;
 
 /**
  * Custom tag that represents an input form, associated with a bean whose
  * properties correspond to the various fields of the form.
  *
- * @author Craig R. McClanahan
- * @author Martin Cooper
- * @author James Turner
- * @author David Graham
- * @version $Revision: 1.48 $ $Date: 2003/05/17 01:56:51 $
+ * @version $Revision: 1.61 $ $Date: 2004/07/22 01:11:42 $
  */
 public class FormTag extends TagSupport {
 
@@ -145,11 +100,6 @@ public class FormTag extends TagSupport {
      */
     protected String method = null;
 
-    /**
-     * The attribute key under which our associated bean is stored.
-     */
-    protected String name = null;
-
     /**
      * The onReset event script.
      */
@@ -161,10 +111,11 @@ public class FormTag extends TagSupport {
     protected String onsubmit = null;
 
     /**
-     * The scope (request or session) under which our associated bean
-     * is stored.
+     * Include language attribute in the focus script's &lt;script&gt; element.  This
+     * property is ignored in XHTML mode.
+     * @since Struts 1.2
      */
-    protected String scope = null;
+    protected boolean scriptLanguage = true;
 
     /**
      * The ActionServlet instance we are associated with (so that we can
@@ -193,11 +144,6 @@ public class FormTag extends TagSupport {
      */
     protected String target = null;
 
-    /**
-     * The Java class name of the bean to be created, if necessary.
-     */
-    protected String type = null;
-
     /**
      * The name of the form bean to (create and) use. This is either the same
      * as the 'name' attribute, if that was specified, or is obtained from the
@@ -219,6 +165,12 @@ public class FormTag extends TagSupport {
      */
     protected String beanType = null;
 
+    /**
+     * The list of character encodings for input data that the server should
+     * accept.
+     */
+    protected String acceptCharset = null;
+
     // ------------------------------------------------------------- Properties
 
     /**
@@ -313,26 +265,6 @@ public class FormTag extends TagSupport {
 
     }
 
-    /**
-     * Return the attribute key name of our bean.
-     */
-    public String getName() {
-
-        return (this.name);
-
-    }
-
-    /**
-     * Set the attribute key name of our bean.
-     *
-     * @param name The new attribute key name
-     */
-    public void setName(String name) {
-
-        this.name = name;
-
-    }
-
     /**
      * Return the onReset event script.
      */
@@ -373,26 +305,6 @@ public class FormTag extends TagSupport {
 
     }
 
-    /**
-     * Return the attribute scope of our bean.
-     */
-    public String getScope() {
-
-        return (this.scope);
-
-    }
-
-    /**
-     * Set the attribute scope of our bean.
-     *
-     * @param scope The new attribute scope
-     */
-    public void setScope(String scope) {
-
-        this.scope = scope;
-
-    }
-
     /**
      * Return the style attribute for this tag.
      */
@@ -474,25 +386,26 @@ public class FormTag extends TagSupport {
     }
 
     /**
-     * Return the Java class of our bean.
+     * Return the list of character encodings accepted.
      */
-    public String getType() {
+    public String getAcceptCharset() {
 
-        return (this.type);
+        return acceptCharset;
 
     }
 
     /**
-     * Set the Java class of our bean.
+     * Set the list of character encodings accepted.
      *
-     * @param type The new Java class
+     * @param acceptCharset The list of character encodings
      */
-    public void setType(String type) {
+    public void setAcceptCharset(String acceptCharset) {
 
-        this.type = type;
+        this.acceptCharset= acceptCharset;
 
     }
 
+
     // --------------------------------------------------------- Public Methods
 
     /**
@@ -512,7 +425,7 @@ public class FormTag extends TagSupport {
 
         results.append(this.renderToken());
 
-        ResponseUtils.write(pageContext, results.toString());
+        TagUtils.getInstance().write(pageContext, results.toString());
 
         // Store this tag itself as a page attribute
         pageContext.setAttribute(Constants.FORM_KEY, this, PageContext.REQUEST_SCOPE);
@@ -536,26 +449,13 @@ public class FormTag extends TagSupport {
         
         Object bean = pageContext.getAttribute(beanName, scope);
         if (bean == null) {
-            if (type != null) {
-                // Backwards compatibility - use explicitly specified values
-                try {
-                    bean = RequestUtils.applicationInstance(beanType);
-                    if (bean != null) {
-                        ((ActionForm) bean).setServlet(servlet);
-                    }
-                } catch (Exception e) {
-                    throw new JspException(
-                        messages.getMessage("formTag.create", type, e.toString()));
-                }
-            } else {
-                // New and improved - use the values from the action mapping
-                bean =
-                    RequestUtils.createActionForm(
-                        (HttpServletRequest) pageContext.getRequest(),
-                        mapping,
-                        moduleConfig,
-                        servlet);
-            }
+            // New and improved - use the values from the action mapping
+            bean =
+                RequestUtils.createActionForm(
+                    (HttpServletRequest) pageContext.getRequest(),
+                    mapping,
+                    moduleConfig,
+                    servlet);
             if (bean instanceof ActionForm) {
                 ((ActionForm) bean).reset(mapping, (HttpServletRequest) pageContext.getRequest());
             }
@@ -573,59 +473,61 @@ public class FormTag extends TagSupport {
      * @since Struts 1.1
      */
     protected String renderFormStartElement() {
-        HttpServletResponse response =
-            (HttpServletResponse) this.pageContext.getResponse();
             
         StringBuffer results = new StringBuffer("<form");
+
+        // render attributes
+        renderName(results);
+        renderAttribute(results, "method", getMethod() == null ? "post" : getMethod());
+        renderAction(results);
+        renderAttribute(results, "accept-charset", getAcceptCharset());
+        renderAttribute(results, "class", getStyleClass());
+        renderAttribute(results, "enctype", getEnctype());
+        renderAttribute(results, "onreset", getOnreset());
+        renderAttribute(results, "onsubmit", getOnsubmit());
+        renderAttribute(results, "style", getStyle());
+        renderAttribute(results, "id", getStyleId());
+        renderAttribute(results, "target", getTarget());
+
+        // Hook for additional attributes
+        renderOtherAttributes(results);
+
+        results.append(">");
+        return results.toString();
+    }
+
+    /**
+     * Renders the name attribute
+     */
+    protected void renderName(StringBuffer results) {
         results.append(" name=\"");
         results.append(beanName);
         results.append("\"");
-        results.append(" method=\"");
-        results.append(method == null ? "post" : method);
-        results.append("\" action=\"");
+    }
+
+    /**
+     * Renders the action attribute
+     */
+    protected void renderAction(StringBuffer results) {
+
+        HttpServletResponse response =
+            (HttpServletResponse) this.pageContext.getResponse();
+
+        results.append(" action=\"");
         results.append(
             response.encodeURL(
-                RequestUtils.getActionMappingURL(this.action, this.pageContext)));
+                TagUtils.getInstance().getActionMappingURL(
+                    this.action,
+                    this.pageContext)));
                 
         results.append("\"");
-        
-        if (styleClass != null) {
-            results.append(" class=\"");
-            results.append(styleClass);
-            results.append("\"");
-        }
-        if (enctype != null) {
-            results.append(" enctype=\"");
-            results.append(enctype);
-            results.append("\"");
-        }
-        if (onreset != null) {
-            results.append(" onreset=\"");
-            results.append(onreset);
-            results.append("\"");
-        }
-        if (onsubmit != null) {
-            results.append(" onsubmit=\"");
-            results.append(onsubmit);
-            results.append("\"");
-        }
-        if (style != null) {
-            results.append(" style=\"");
-            results.append(style);
-            results.append("\"");
-        }
-        if (styleId != null) {
-            results.append(" id=\"");
-            results.append(styleId);
-            results.append("\"");
-        }
-        if (target != null) {
-            results.append(" target=\"");
-            results.append(target);
-            results.append("\"");
-        }
-        results.append(">");
-        return results.toString();
+    }
+
+    /**
+     * 'Hook' to enable this tag to be extended and 
+     *  additional attributes added.
+     */
+    protected void renderOtherAttributes(StringBuffer results) {
     }
 
     /**
@@ -657,6 +559,19 @@ public class FormTag extends TagSupport {
         return results.toString();
     }
 
+    /**
+     * Renders attribute="value" if not null
+     */
+    protected void renderAttribute(StringBuffer results, String attribute, String value) {
+        if (value != null) {
+            results.append(" ");
+            results.append(attribute);
+            results.append("=\"");
+            results.append(value);
+            results.append("\"");
+        }
+    }
+
     /**
      * Render the end of this form.
      *
@@ -699,7 +614,7 @@ public class FormTag extends TagSupport {
 
         results.append(lineEnd);
         results.append("<script type=\"text/javascript\"");
-        if (!this.isXhtml()) {
+        if (!this.isXhtml() && this.scriptLanguage) {
             results.append(" language=\"JavaScript\"");
         }
         results.append(">");
@@ -725,7 +640,7 @@ public class FormTag extends TagSupport {
         results.append(lineEnd);
         results.append(lineEnd);
 
-        results.append("  if (focusControl.type != \"hidden\") {");
+        results.append("  if (focusControl.type != \"hidden\" && !focusControl.disabled) {");
         results.append(lineEnd);
 
         // Construct the index if needed and insert into focus statement
@@ -767,16 +682,14 @@ public class FormTag extends TagSupport {
         focusIndex = null;
         mapping = null;
         method = null;
-        name = null;
         onreset = null;
         onsubmit = null;
-        scope = null;
         servlet = null;
         style = null;
         styleClass = null;
         styleId = null;
         target = null;
-        type = null;
+        acceptCharset = null;
 
     }
 
@@ -792,7 +705,7 @@ public class FormTag extends TagSupport {
     protected void lookup() throws JspException {
 
         // Look up the module configuration information we need
-        moduleConfig = RequestUtils.getModuleConfig(pageContext);
+        moduleConfig = TagUtils.getInstance().getModuleConfig(pageContext);
 
         if (moduleConfig == null) {
             JspException e = new JspException(messages.getMessage("formTag.collections"));
@@ -804,7 +717,7 @@ public class FormTag extends TagSupport {
                 Globals.ACTION_SERVLET_KEY);
 
         // Look up the action mapping we will be submitting to
-        String mappingName = RequestUtils.getActionMappingName(action);
+        String mappingName = TagUtils.getInstance().getActionMappingName(action);
         mapping = (ActionMapping) moduleConfig.findActionConfig(mappingName);
         if (mapping == null) {
             JspException e = new JspException(messages.getMessage("formTag.mapping", mappingName));
@@ -812,24 +725,11 @@ public class FormTag extends TagSupport {
             throw e;
         }
 
-        // Were the required values already specified?
-        if (name != null) {
-            if (type == null) {
-                JspException e = new JspException(messages.getMessage("formTag.nameType"));
-                pageContext.setAttribute(Globals.EXCEPTION_KEY, e, PageContext.REQUEST_SCOPE);
-                throw e;
-            }
-            beanName = name;
-            beanScope = (scope == null ? "session" : scope);
-            beanType = type;
-            return;
-        }
-
         // Look up the form bean definition
         FormBeanConfig formBeanConfig = moduleConfig.findFormBeanConfig(mapping.getName());
         if (formBeanConfig == null) {
             JspException e =
-                new JspException(messages.getMessage("formTag.formBean", mapping.getName()));
+                new JspException(messages.getMessage("formTag.formBean", mapping.getName(), action));
             pageContext.setAttribute(Globals.EXCEPTION_KEY, e, PageContext.REQUEST_SCOPE);
             throw e;
         }
@@ -844,7 +744,7 @@ public class FormTag extends TagSupport {
      * Returns true if this tag should render as xhtml.
      */
     private boolean isXhtml() {
-        return RequestUtils.isXhtml(this.pageContext);
+        return TagUtils.getInstance().isXhtml(this.pageContext);
     }
 
     /**
@@ -863,4 +763,23 @@ public class FormTag extends TagSupport {
         this.focusIndex = focusIndex;
     }
 
+    /**
+     * Gets whether or not the focus script's &lt;script&gt; element will include the 
+     * language attribute.
+     * @return true if language attribute will be included.
+     * @since Struts 1.2
+     */
+    public boolean getScriptLanguage() {
+        return this.scriptLanguage;
+    }
+
+    /**
+     * Sets whether or not the focus script's &lt;script&gt; element will include the 
+     * language attribute.
+     * @since Struts 1.2
+     */
+    public void setScriptLanguage(boolean scriptLanguage) {
+        this.scriptLanguage = scriptLanguage;
+    }
+
 }
