@@ -1,62 +1,21 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/upload/CommonsMultipartRequestHandler.java,v 1.10 2003/05/02 04:35:42 rleland Exp $
- * $Revision: 1.10 $
- * $Date: 2003/05/02 04:35:42 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/upload/CommonsMultipartRequestHandler.java,v 1.18 2004/04/18 22:02:14 martinc Exp $
+ * $Revision: 1.18 $
+ * $Date: 2004/04/18 22:02:14 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
@@ -67,6 +26,7 @@ import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.InputStream;
 import java.io.IOException;
+import java.io.Serializable;
 import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.List;
@@ -88,8 +48,7 @@ import org.apache.struts.Globals;
   * This class implements the <code>MultipartRequestHandler</code> interface
   * by providing a wrapper around the Jakarta Commons FileUpload library.
   *
-  * @author Martin Cooper
-  * @version $Revision: 1.10 $ $Date: 2003/05/02 04:35:42 $
+  * @version $Revision: 1.18 $ $Date: 2004/04/18 22:02:14 $
   * @since Struts 1.1
   */
 public class CommonsMultipartRequestHandler implements MultipartRequestHandler {
@@ -215,8 +174,11 @@ public class CommonsMultipartRequestHandler implements MultipartRequestHandler {
 
         // Create and configure a DIskFileUpload instance.
         DiskFileUpload upload = new DiskFileUpload();
+        // The following line is to support an "EncodingFilter"
+        // see http://nagoya.apache.org/bugzilla/show_bug.cgi?id=23255
+        upload.setHeaderEncoding(request.getCharacterEncoding());
         // Set the maximum size before a FileUploadException will be thrown.
-        upload.setSizeMax((int) getSizeMax(ac));
+        upload.setSizeMax(getSizeMax(ac));
         // Set the maximum size that will be stored in memory.
         upload.setSizeThreshold((int) getSizeThreshold(ac));
         // Set the the location for saving data on disk.
@@ -444,11 +406,24 @@ public class CommonsMultipartRequestHandler implements MultipartRequestHandler {
     protected void addTextParameter(HttpServletRequest request, FileItem item) {
         String name = item.getFieldName();
         String value = null;
+        boolean haveValue = false;
+        String encoding = request.getCharacterEncoding();
 
-        try {
-            value = item.getString(request.getCharacterEncoding());
-        } catch (Exception e) {
-            value = item.getString();
+        if (encoding != null) {
+            try {
+                value = item.getString(encoding);
+                haveValue = true;
+            } catch (Exception e) {
+                // Handled below, since haveValue is false.
+            }
+        }
+        if (!haveValue) {
+            try {
+                 value = item.getString("ISO-8859-1");
+            } catch (java.io.UnsupportedEncodingException uee) {
+                 value = item.getString();
+            }
+            haveValue = true;
         }
 
         if (request instanceof MultipartRequestWrapper) {
@@ -495,7 +470,7 @@ public class CommonsMultipartRequestHandler implements MultipartRequestHandler {
      * implementation is <i>read-only</i>; any attempt to modify an instance
      * of this class will result in an <code>UnsupportedOperationException</code>.
      */
-    static class CommonsFormFile implements FormFile {
+    static class CommonsFormFile implements FormFile, Serializable {
 
         /**
          * The <code>FileItem</code> instance wrapped by this object.
