@@ -1,76 +1,33 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/util/MessageResources.java,v 1.16 2002/11/09 04:04:11 dmkarr Exp $
- * $Revision: 1.16 $
- * $Date: 2002/11/09 04:04:11 $
+ * $Header: /home/cvs/jakarta-struts/src/share/org/apache/struts/util/MessageResources.java,v 1.23 2004/03/14 06:23:51 sraeburn Exp $
+ * $Revision: 1.23 $
+ * $Date: 2004/03/14 06:23:51 $
  *
- * ====================================================================
+ * Copyright 1999-2004 The Apache Software Foundation.
  * 
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights 
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:  
- *       "This product includes software developed by the 
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written 
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- */ 
-
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.apache.struts.util;
 
-
 import java.io.Serializable;
 import java.text.MessageFormat;
 import java.util.HashMap;
 import java.util.Locale;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-
 /**
  * General purpose abstract class that describes an API for retrieving
  * Locale-sensitive messages from underlying resource locations of an
@@ -90,13 +47,10 @@ import org.apache.commons.logging.LogFactory;
  * must be Serializable so that instances may be used in distributable
  * application server environments.
  *
- * @author Craig R. McClanahan
- * @version $Revision: 1.16 $ $Date: 2002/11/09 04:04:11 $
+ * @version $Revision: 1.23 $ $Date: 2004/03/14 06:23:51 $
  */
-
 public abstract class MessageResources implements Serializable {
 
-
     // ------------------------------------------------------------- Properties
 
     /**
@@ -104,7 +58,6 @@ public abstract class MessageResources implements Serializable {
      */
     protected static Log log = LogFactory.getLog(MessageResources.class);
 
-
     /**
      * The configuration parameter used to initialize this MessageResources.
      */
@@ -118,13 +71,11 @@ public abstract class MessageResources implements Serializable {
         return (this.config);
     }
 
-
     /**
      * The default Locale for our environment.
      */
     protected Locale defaultLocale = Locale.getDefault();
 
-
     /**
      * The <code>MessageResourcesFactory</code> that created this instance.
      */
@@ -138,14 +89,12 @@ public abstract class MessageResources implements Serializable {
         return (this.factory);
     }
 
-
     /**
      * The set of previously created MessageFormat objects, keyed by the
      * key computed in <code>messageKey()</code>.
      */
     protected HashMap formats = new HashMap();
 
-
     /**
      * Indicate is a <code>null</code> is returned instead of an error message string
      * when an unknown Locale or key is requested.
@@ -171,10 +120,8 @@ public abstract class MessageResources implements Serializable {
         this.returnNull = returnNull;
     }
 
-
     // ----------------------------------------------------------- Constructors
 
-
     /**
      * Construct a new MessageResources according to the specified parameters.
      *
@@ -187,7 +134,6 @@ public abstract class MessageResources implements Serializable {
 
     }
 
-
     /**
      * Construct a new MessageResources according to the specified parameters.
      *
@@ -195,8 +141,10 @@ public abstract class MessageResources implements Serializable {
      * @param config The configuration parameter for this MessageResources
      * @param returnNull The returnNull property we should initialize with
      */
-    public MessageResources(MessageResourcesFactory factory, String config,
-                         boolean returnNull) {
+    public MessageResources(
+        MessageResourcesFactory factory,
+        String config,
+        boolean returnNull) {
 
         super();
         this.factory = factory;
@@ -205,11 +153,8 @@ public abstract class MessageResources implements Serializable {
 
     }
 
-
     // --------------------------------------------------------- Public Methods
 
-
-
     /**
      * Returns a text message for the specified key, for the default Locale.
      *
@@ -217,11 +162,10 @@ public abstract class MessageResources implements Serializable {
      */
     public String getMessage(String key) {
 
-	return (getMessage((Locale) null, key));
+        return this.getMessage((Locale) null, key, null);
 
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.
@@ -231,11 +175,10 @@ public abstract class MessageResources implements Serializable {
      */
     public String getMessage(String key, Object args[]) {
 
-	return (getMessage((Locale) null, key, args));
+        return this.getMessage((Locale) null, key, args);
 
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.
@@ -245,11 +188,10 @@ public abstract class MessageResources implements Serializable {
      */
     public String getMessage(String key, Object arg0) {
 
-	return (getMessage((Locale) null, key, arg0));
+        return this.getMessage((Locale) null, key, arg0);
 
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.
@@ -260,11 +202,10 @@ public abstract class MessageResources implements Serializable {
      */
     public String getMessage(String key, Object arg0, Object arg1) {
 
-	return (getMessage((Locale) null, key, arg0, arg1));
+        return this.getMessage((Locale) null, key, arg0, arg1);
 
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.
@@ -274,14 +215,12 @@ public abstract class MessageResources implements Serializable {
      * @param arg1 The replacement for placeholder {1} in the message
      * @param arg2 The replacement for placeholder {2} in the message
      */
-    public String getMessage(String key, Object arg0, Object arg1,
-			     Object arg2) {
+    public String getMessage(String key, Object arg0, Object arg1, Object arg2) {
 
-	return (getMessage((Locale) null, key, arg0, arg1, arg2));
+        return this.getMessage((Locale) null, key, arg0, arg1, arg2);
 
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.
@@ -292,14 +231,17 @@ public abstract class MessageResources implements Serializable {
      * @param arg2 The replacement for placeholder {2} in the message
      * @param arg3 The replacement for placeholder {3} in the message
      */
-    public String getMessage(String key, Object arg0, Object arg1,
-			     Object arg2, Object arg3) {
+    public String getMessage(
+        String key,
+        Object arg0,
+        Object arg1,
+        Object arg2,
+        Object arg3) {
 
-	return (getMessage((Locale) null, key, arg0, arg1, arg2, arg3));
+        return this.getMessage((Locale) null, key, arg0, arg1, arg2, arg3);
 
     }
 
-
     /**
      * Returns a text message for the specified key, for the default Locale.
      * A null string result will be returned by this method if no relevant
@@ -315,7 +257,6 @@ public abstract class MessageResources implements Serializable {
      */
     public abstract String getMessage(Locale locale, String key);
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.  A null string result will be returned by
@@ -328,31 +269,33 @@ public abstract class MessageResources implements Serializable {
      */
     public String getMessage(Locale locale, String key, Object args[]) {
 
-	// Cache MessageFormat instances as they are accessed
-        if (locale == null)
+        // Cache MessageFormat instances as they are accessed
+        if (locale == null) {
             locale = defaultLocale;
-	MessageFormat format = null;
-	String formatKey = messageKey(locale, key);
-	synchronized (formats) {
-	    format = (MessageFormat) formats.get(formatKey);
-	    if (format == null) {
-		String formatString = getMessage(locale, key);
-		if (formatString == null) {
-		    if (returnNull)
-			return (null);
-		    else
-			return ("???" + formatKey + "???");
-		}
-		format = new MessageFormat(escape(formatString));
-		formats.put(formatKey, format);
-	    }
+        }
 
-	}
-	return (format.format(args));
+        MessageFormat format = null;
+        String formatKey = messageKey(locale, key);
 
+        synchronized (formats) {
+            format = (MessageFormat) formats.get(formatKey);
+            if (format == null) {
+                String formatString = getMessage(locale, key);
+
+                if (formatString == null) {
+                    return returnNull ? null : ("???" + formatKey + "???");
+                }
+
+                format = new MessageFormat(escape(formatString));
+                format.setLocale(locale);
+                formats.put(formatKey, format);
+            }
+
+        }
+
+        return format.format(args);
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.  A null string result will never be returned
@@ -364,14 +307,9 @@ public abstract class MessageResources implements Serializable {
      * @param arg0 The replacement for placeholder {0} in the message
      */
     public String getMessage(Locale locale, String key, Object arg0) {
-
-	Object args[] = new Object[1];
-	args[0] = arg0;
-	return (getMessage(locale, key, args));
-
+        return this.getMessage(locale, key, new Object[] { arg0 });
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.  A null string result will never be returned
@@ -383,17 +321,10 @@ public abstract class MessageResources implements Serializable {
      * @param arg0 The replacement for placeholder {0} in the message
      * @param arg1 The replacement for placeholder {1} in the message
      */
-    public String getMessage(Locale locale,
-			     String key, Object arg0, Object arg1) {
-
-	Object args[] = new Object[2];
-	args[0] = arg0;
-	args[1] = arg1;
-	return (getMessage(locale, key, args));
-
+    public String getMessage(Locale locale, String key, Object arg0, Object arg1) {
+        return this.getMessage(locale, key, new Object[] { arg0, arg1 });
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.  A null string result will never be returned
@@ -406,19 +337,16 @@ public abstract class MessageResources implements Serializable {
      * @param arg1 The replacement for placeholder {1} in the message
      * @param arg2 The replacement for placeholder {2} in the message
      */
-    public String getMessage(Locale locale,
-			     String key, Object arg0, Object arg1,
-			     Object arg2) {
-
-	Object args[] = new Object[3];
-	args[0] = arg0;
-	args[1] = arg1;
-	args[2] = arg2;
-	return (getMessage(locale, key, args));
+    public String getMessage(
+        Locale locale,
+        String key,
+        Object arg0,
+        Object arg1,
+        Object arg2) {
 
+        return this.getMessage(locale, key, new Object[] { arg0, arg1, arg2 });
     }
 
-
     /**
      * Returns a text message after parametric replacement of the specified
      * parameter placeholders.  A null string result will never be returned
@@ -432,20 +360,17 @@ public abstract class MessageResources implements Serializable {
      * @param arg2 The replacement for placeholder {2} in the message
      * @param arg3 The replacement for placeholder {3} in the message
      */
-    public String getMessage(Locale locale,
-			     String key, Object arg0, Object arg1,
-			     Object arg2, Object arg3) {
-
-	Object args[] = new Object[4];
-	args[0] = arg0;
-	args[1] = arg1;
-	args[2] = arg2;
-	args[3] = arg3;
-	return (getMessage(locale, key, args));
+    public String getMessage(
+        Locale locale,
+        String key,
+        Object arg0,
+        Object arg1,
+        Object arg2,
+        Object arg3) {
 
+        return this.getMessage(locale, key, new Object[] { arg0, arg1, arg2, arg3 });
     }
 
-
     /**
      * Return <code>true</code> if there is a defined message for the specified
      * key in the system default locale.
@@ -454,11 +379,10 @@ public abstract class MessageResources implements Serializable {
      */
     public boolean isPresent(String key) {
 
-        return (isPresent(null, key));
+        return this.isPresent(null, key);
 
     }
 
-
     /**
      * Return <code>true</code> if there is a defined message for the specified
      * key in the specified Locale.
@@ -470,19 +394,21 @@ public abstract class MessageResources implements Serializable {
     public boolean isPresent(Locale locale, String key) {
 
         String message = getMessage(locale, key);
-        if (message == null)
-            return (false);
-        else if (message.startsWith("???") && message.endsWith("???"))
-            return (false); // FIXME - Only valid for default implementation
-        else
-            return (true);
+
+        if (message == null) {
+            return false;
+
+        } else if (message.startsWith("???") && message.endsWith("???")) {
+            return false; // FIXME - Only valid for default implementation
+
+        } else {
+            return true;
+        }
 
     }
 
-
     // ------------------------------------------------------ Protected Methods
 
-
     /**
      * Escape any single quote characters that are included in the specified
      * message string.
@@ -491,21 +417,27 @@ public abstract class MessageResources implements Serializable {
      */
     protected String escape(String string) {
 
-        if ((string == null) || (string.indexOf('\'') < 0))
-            return (string);
+        if ((string == null) || (string.indexOf('\'') < 0)) {
+            return string;
+        }
+
         int n = string.length();
         StringBuffer sb = new StringBuffer(n);
+
         for (int i = 0; i < n; i++) {
             char ch = string.charAt(i);
-            if (ch == '\'')
+
+            if (ch == '\'') {
                 sb.append('\'');
+            }
+
             sb.append(ch);
         }
-        return (sb.toString());
+
+        return sb.toString();
 
     }
 
-
     /**
      * Compute and return a key to be used in caching information by a Locale.
      * <strong>NOTE</strong> - The locale key for the default Locale in our
@@ -514,17 +446,9 @@ public abstract class MessageResources implements Serializable {
      * @param locale The locale for which a key is desired
      */
     protected String localeKey(Locale locale) {
-
-        if (locale == null)
-            return ("");
-        //        else if (locale.equals(defaultLocale))
-        //            return ("");
-        else
-            return (locale.toString());
-
+        return (locale == null) ? "" : locale.toString();
     }
 
-
     /**
      * Compute and return a key to be used in caching information
      * by Locale and message key.
@@ -538,7 +462,6 @@ public abstract class MessageResources implements Serializable {
 
     }
 
-
     /**
      * Compute and return a key to be used in caching information
      * by locale key and message key.
@@ -552,33 +475,29 @@ public abstract class MessageResources implements Serializable {
 
     }
 
-
     // --------------------------------------------------------- Static Methods
 
-
     /**
      * The default MessageResourcesFactory used to create MessageResources
      * instances.
      */
     protected static MessageResourcesFactory defaultFactory = null;
 
-
     /**
      * Create and return an instance of <code>MessageResources</code> for the
      * created by the default <code>MessageResourcesFactory</code>.
      *
      * @param config Configuration parameter for this message bundle.
      */
-    public synchronized static MessageResources
-        getMessageResources(String config) {
+    public synchronized static MessageResources getMessageResources(String config) {
 
-        if (defaultFactory == null)
+        if (defaultFactory == null) {
             defaultFactory = MessageResourcesFactory.createFactory();
+        }
+
         return defaultFactory.createResources(config);
-
     }
 
-
     /**
      * Log a message to the Writer that has been configured for our use.
      *
@@ -588,7 +507,6 @@ public abstract class MessageResources implements Serializable {
         log.debug(message);
     }
 
-
     /**
      * Log a message and exception to the Writer that has been configured
      * for our use.
@@ -600,5 +518,4 @@ public abstract class MessageResources implements Serializable {
         log.debug(message, throwable);
     }
 
-
 }
