@@ -1,56 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/test/org/apache/struts/action/TestDynaActionForm.java,v 1.15 2004/03/14 06:23:51 sraeburn Exp $
+ * $Revision: 1.15 $
+ * $Date: 2004/03/14 06:23:51 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package org.apache.struts.action;
 
@@ -64,9 +29,11 @@ import junit.framework.Test;
 import junit.framework.TestSuite;
 
 import org.apache.commons.beanutils.DynaProperty;
-import org.apache.struts.config.ApplicationConfig;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.apache.struts.config.FormBeanConfig;
 import org.apache.struts.config.ModuleConfig;
+import org.apache.struts.config.impl.ModuleConfigImpl;
 
 
 /**
@@ -114,9 +81,9 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
 
 
     /**
-     * Dummy ApplicationConfig for calls to reset() and validate().
+     * Dummy ModuleConfig for calls to reset() and validate().
      */
-    protected ApplicationConfig appConfig = null;
+    protected ModuleConfig moduleConfig = null;
 
 
     /**
@@ -131,6 +98,8 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
     protected ActionMapping mapping = null;
 
 
+    protected Log log = null;
+
     /**
      * The set of property names we expect to have returned when calling
      * <code>getDynaProperties()</code>.  You should update this list
@@ -170,9 +139,9 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
             throw new RuntimeException(e.getMessage());
         }
         setupComplexProperties();
-        appConfig = new DynaActionFormConfig(beanConfig);
-        mapping = new DynaActionFormMapping(appConfig);
-
+        moduleConfig = new DynaActionFormConfig(beanConfig);
+        mapping = new DynaActionFormMapping(moduleConfig);
+        log = LogFactory.getLog(this.getClass().getName() + "." + this.getName());
 
     }
 
@@ -180,7 +149,7 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
     public void tearDown() {
 
         super.tearDown();
-        appConfig = null;
+        moduleConfig = null;
         dynaForm = null;
         mapping = null;
 
@@ -278,22 +247,16 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testGetDescriptorArguments() {
 
-        try {
-            DynaProperty descriptor =
-                    dynaForm.getDynaClass().getDynaProperty("unknown");
-            assertNull("Unknown property descriptor should be null",
-                    descriptor);
-        } catch (Throwable t) {
-            fail("Threw " + t + " instead of returning null");
-        }
+        DynaProperty descriptor =
+            dynaForm.getDynaClass().getDynaProperty("unknown");
+        assertNull("Unknown property descriptor should be null",
+            descriptor);
 
         try {
             dynaForm.getDynaClass().getDynaProperty(null);
             fail("Should throw IllegalArgumentException");
         } catch (IllegalArgumentException e) {
             ; // Expected response
-        } catch (Throwable t) {
-            fail("Threw " + t + " instead of IllegalArgumentException");
         }
 
     }
@@ -416,11 +379,8 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
             fail("Should throw IndexOutOfBoundsException");
         } catch (IndexOutOfBoundsException e) {
             ; // Expected response
-        } catch (Throwable t) {
-            fail("Threw " + t + " instead of IndexOutOfBoundsException");
         }
 
-
     }
 
 
@@ -433,60 +393,40 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
 
         for (int i = 0; i < 5; i++) {
 
-            try {
-                value = dynaForm.get("intArray", i);
-                assertNotNull("intArray returned value " + i, value);
-                assertTrue("intArray returned Integer " + i,
-                        value instanceof Integer);
-                assertEquals("intArray returned correct " + i, i * 10,
-                        ((Integer) value).intValue());
-            } catch (Throwable t) {
-                fail("intArray " + i + " threw " + t);
-            }
+            value = dynaForm.get("intArray", i);
+            assertNotNull("intArray returned value " + i, value);
+            assertTrue("intArray returned Integer " + i,
+                    value instanceof Integer);
+            assertEquals("intArray returned correct " + i, i * 10,
+                    ((Integer) value).intValue());
 
-            try {
-                value = dynaForm.get("intIndexed", i);
-                assertNotNull("intIndexed returned value " + i, value);
-                assertTrue("intIndexed returned Integer " + i,
-                        value instanceof Integer);
-                assertEquals("intIndexed returned correct " + i, i * 100,
-                        ((Integer) value).intValue());
-            } catch (Throwable t) {
-                fail("intIndexed " + i + " threw " + t);
-            }
+            value = dynaForm.get("intIndexed", i);
+            assertNotNull("intIndexed returned value " + i, value);
+            assertTrue("intIndexed returned Integer " + i,
+                    value instanceof Integer);
+            assertEquals("intIndexed returned correct " + i, i * 100,
+                    ((Integer) value).intValue());
 
-            try {
-                value = dynaForm.get("listIndexed", i);
-                assertNotNull("listIndexed returned value " + i, value);
-                assertTrue("list returned String " + i,
-                        value instanceof String);
-                assertEquals("listIndexed returned correct " + i,
-                        "String " + i, (String) value);
-            } catch (Throwable t) {
-                fail("listIndexed " + i + " threw " + t);
-            }
+            value = dynaForm.get("listIndexed", i);
+            assertNotNull("listIndexed returned value " + i, value);
+            assertTrue("list returned String " + i,
+                    value instanceof String);
+            assertEquals("listIndexed returned correct " + i,
+                    "String " + i, (String) value);
 
-            try {
-                value = dynaForm.get("stringArray", i);
-                assertNotNull("stringArray returned value " + i, value);
-                assertTrue("stringArray returned String " + i,
-                        value instanceof String);
-                assertEquals("stringArray returned correct " + i,
-                        "String " + i, (String) value);
-            } catch (Throwable t) {
-                fail("stringArray " + i + " threw " + t);
-            }
+            value = dynaForm.get("stringArray", i);
+            assertNotNull("stringArray returned value " + i, value);
+            assertTrue("stringArray returned String " + i,
+                    value instanceof String);
+            assertEquals("stringArray returned correct " + i,
+                    "String " + i, (String) value);
 
-            try {
-                value = dynaForm.get("stringIndexed", i);
-                assertNotNull("stringIndexed returned value " + i, value);
-                assertTrue("stringIndexed returned String " + i,
-                        value instanceof String);
-                assertEquals("stringIndexed returned correct " + i,
-                        "String " + i, (String) value);
-            } catch (Throwable t) {
-                fail("stringIndexed " + i + " threw " + t);
-            }
+            value = dynaForm.get("stringIndexed", i);
+            assertNotNull("stringIndexed returned value " + i, value);
+            assertTrue("stringIndexed returned String " + i,
+                    value instanceof String);
+            assertEquals("stringIndexed returned correct " + i,
+                    "String " + i, (String) value);
 
         }
 
@@ -498,16 +438,8 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      * Corner cases on getMappedProperty invalid arguments.
      */
     public void testGetMappedArguments() {
-
-
-        try {
-            Object value = dynaForm.get("mappedProperty", "unknown");
-            assertNull("Should not return a value", value);
-        } catch (Throwable t) {
-            fail("Threw " + t + " instead of returning null");
-        }
-
-
+        Object value = dynaForm.get("mappedProperty", "unknown");
+        assertNull("Should not return a value", value);
     }
 
 
@@ -518,26 +450,14 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
 
         Object value = null;
 
-        try {
-            value = dynaForm.get("mappedProperty", "First Key");
-            assertEquals("Can find first value", "First Value", value);
-        } catch (Throwable t) {
-            fail("Finding first value threw " + t);
-        }
+        value = dynaForm.get("mappedProperty", "First Key");
+        assertEquals("Can find first value", "First Value", value);
 
-        try {
-            value = dynaForm.get("mappedProperty", "Second Key");
-            assertEquals("Can find second value", "Second Value", value);
-        } catch (Throwable t) {
-            fail("Finding second value threw " + t);
-        }
+        value = dynaForm.get("mappedProperty", "Second Key");
+        assertEquals("Can find second value", "Second Value", value);
 
-        try {
-            value = dynaForm.get("mappedProperty", "Third Key");
-            assertNull("Can not find third value", value);
-        } catch (Throwable t) {
-            fail("Finding third value threw " + t);
-        }
+        value = dynaForm.get("mappedProperty", "Third Key");
+        assertNull("Can not find third value", value);
 
     }
 
@@ -552,8 +472,6 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
             fail("Should throw IllegalArgumentException");
         } catch (IllegalArgumentException e) {
             ; // Expected response
-        } catch (Throwable t) {
-            fail("Threw " + t + " instead of IllegalArgumentException");
         }
 
     }
@@ -564,16 +482,11 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testGetSimpleBoolean() {
 
-        try {
-            Object value = dynaForm.get("booleanProperty");
-            assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Boolean));
-            assertTrue("Got correct value",
-                    ((Boolean) value).booleanValue() == true);
-        } catch (Throwable e) {
-            fail("Exception: " + e);
-        }
-
+        Object value = dynaForm.get("booleanProperty");
+        assertNotNull("Got a value", value);
+        assertTrue("Got correct type", (value instanceof Boolean));
+        assertTrue("Got correct value",
+                ((Boolean) value).booleanValue() == true);
     }
 
 
@@ -582,7 +495,6 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testGetSimpleDouble() {
 
-        try {
             Object value = dynaForm.get("doubleProperty");
             assertNotNull("Got a value", value);
             assertTrue("Got correct type", (value instanceof Double));
@@ -590,9 +502,6 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
                     ((Double) value).doubleValue(),
                     (double) 321.0,
                     (double) 0.005);
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
 
     }
 
@@ -602,17 +511,13 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testGetSimpleFloat() {
 
-        try {
-            Object value = dynaForm.get("floatProperty");
-            assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Float));
-            assertEquals("Got correct value",
-                    ((Float) value).floatValue(),
-                    (float) 123.0,
-                    (float) 0.005);
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        Object value = dynaForm.get("floatProperty");
+        assertNotNull("Got a value", value);
+        assertTrue("Got correct type", (value instanceof Float));
+        assertEquals("Got correct value",
+                ((Float) value).floatValue(),
+                (float) 123.0,
+                (float) 0.005);
 
     }
 
@@ -622,16 +527,12 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testGetSimpleInt() {
 
-        try {
-            Object value = dynaForm.get("intProperty");
-            assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Integer));
-            assertEquals("Got correct value",
-                    ((Integer) value).intValue(),
-                    (int) 123);
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        Object value = dynaForm.get("intProperty");
+        assertNotNull("Got a value", value);
+        assertTrue("Got correct type", (value instanceof Integer));
+        assertEquals("Got correct value",
+                ((Integer) value).intValue(),
+                (int) 123);
 
     }
 
@@ -641,16 +542,12 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testGetSimpleLong() {
 
-        try {
-            Object value = dynaForm.get("longProperty");
-            assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Long));
-            assertEquals("Got correct value",
-                    ((Long) value).longValue(),
-                    (long) 321);
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        Object value = dynaForm.get("longProperty");
+        assertNotNull("Got a value", value);
+        assertTrue("Got correct type", (value instanceof Long));
+        assertEquals("Got correct value",
+                ((Long) value).longValue(),
+                (long) 321);
 
     }
 
@@ -660,16 +557,12 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testGetSimpleShort() {
 
-        try {
-            Object value = dynaForm.get("shortProperty");
-            assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Short));
-            assertEquals("Got correct value",
-                    ((Short) value).shortValue(),
-                    (short) 987);
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        Object value = dynaForm.get("shortProperty");
+        assertNotNull("Got a value", value);
+        assertTrue("Got correct type", (value instanceof Short));
+        assertEquals("Got correct value",
+                ((Short) value).shortValue(),
+                (short) 987);
 
     }
 
@@ -679,16 +572,12 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testGetSimpleString() {
 
-        try {
-            Object value = dynaForm.get("stringProperty");
-            assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof String));
-            assertEquals("Got correct value",
-                    (String) value,
-                    "This is a string");
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        Object value = dynaForm.get("stringProperty");
+        assertNotNull("Got a value", value);
+        assertTrue("Got correct type", (value instanceof String));
+        assertEquals("Got correct value",
+                (String) value,
+                "This is a string");
 
     }
 
@@ -698,20 +587,11 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testMappedContains() {
 
-        try {
-            assertTrue("Can see first key",
-                    dynaForm.contains("mappedProperty", "First Key"));
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        assertTrue("Can see first key",
+                dynaForm.contains("mappedProperty", "First Key"));
 
-
-        try {
-            assertTrue("Can not see unknown key",
-                    !dynaForm.contains("mappedProperty", "Unknown Key"));
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        assertTrue("Can not see unknown key",
+                !dynaForm.contains("mappedProperty", "Unknown Key"));
 
     }
 
@@ -721,25 +601,17 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testMappedRemove() {
 
-        try {
-            assertTrue("Can see first key",
-                    dynaForm.contains("mappedProperty", "First Key"));
-            dynaForm.remove("mappedProperty", "First Key");
-            assertTrue("Can not see first key",
-                    !dynaForm.contains("mappedProperty", "First Key"));
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        assertTrue("Can see first key",
+                dynaForm.contains("mappedProperty", "First Key"));
+        dynaForm.remove("mappedProperty", "First Key");
+        assertTrue("Can not see first key",
+                !dynaForm.contains("mappedProperty", "First Key"));
 
-        try {
-            assertTrue("Can not see unknown key",
-                    !dynaForm.contains("mappedProperty", "Unknown Key"));
-            dynaForm.remove("mappedProperty", "Unknown Key");
-            assertTrue("Can not see unknown key",
-                    !dynaForm.contains("mappedProperty", "Unknown Key"));
-        } catch (Throwable t) {
-            fail("Exception: " + t);
-        }
+        assertTrue("Can not see unknown key",
+                !dynaForm.contains("mappedProperty", "Unknown Key"));
+        dynaForm.remove("mappedProperty", "Unknown Key");
+        assertTrue("Can not see unknown key",
+                !dynaForm.contains("mappedProperty", "Unknown Key"));
 
     }
 
@@ -754,8 +626,6 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
             fail("Should throw IndexOutOfBoundsException");
         } catch (IndexOutOfBoundsException e) {
             ; // Expected response
-        } catch (Throwable t) {
-            fail("Threw " + t + " instead of IndexOutOfBoundsException");
         }
 
     }
@@ -768,65 +638,44 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
 
         Object value = null;
 
-        try {
-            dynaForm.set("intArray", 0, new Integer(1));
-            value = (Integer) dynaForm.get("intArray", 0);
-            assertNotNull("Returned new value 0", value);
-            assertTrue("Returned Integer new value 0",
-                    value instanceof Integer);
-            assertEquals("Returned correct new value 0", 1,
-                    ((Integer) value).intValue());
-        } catch (Throwable t) {
-            fail("Threw " + t);
-        }
+        dynaForm.set("intArray", 0, new Integer(1));
+        value = (Integer) dynaForm.get("intArray", 0);
+        assertNotNull("Returned new value 0", value);
+        assertTrue("Returned Integer new value 0",
+                value instanceof Integer);
+        assertEquals("Returned correct new value 0", 1,
+                ((Integer) value).intValue());
 
-        try {
-            dynaForm.set("intIndexed", 1, new Integer(11));
-            value = (Integer) dynaForm.get("intIndexed", 1);
-            assertNotNull("Returned new value 1", value);
-            assertTrue("Returned Integer new value 1",
-                    value instanceof Integer);
-            assertEquals("Returned correct new value 1", 11,
-                    ((Integer) value).intValue());
-        } catch (Throwable t) {
-            fail("Threw " + t);
-        }
+        dynaForm.set("intIndexed", 1, new Integer(11));
+        value = (Integer) dynaForm.get("intIndexed", 1);
+        assertNotNull("Returned new value 1", value);
+        assertTrue("Returned Integer new value 1",
+                value instanceof Integer);
+        assertEquals("Returned correct new value 1", 11,
+                ((Integer) value).intValue());
+        dynaForm.set("listIndexed", 2, "New Value 2");
+        value = (String) dynaForm.get("listIndexed", 2);
+        assertNotNull("Returned new value 2", value);
+        assertTrue("Returned String new value 2",
+                value instanceof String);
+        assertEquals("Returned correct new value 2", "New Value 2",
+                (String) value);
 
-        try {
-            dynaForm.set("listIndexed", 2, "New Value 2");
-            value = (String) dynaForm.get("listIndexed", 2);
-            assertNotNull("Returned new value 2", value);
-            assertTrue("Returned String new value 2",
-                    value instanceof String);
-            assertEquals("Returned correct new value 2", "New Value 2",
-                    (String) value);
-        } catch (Throwable t) {
-            fail("Threw " + t);
-        }
+        dynaForm.set("stringArray", 3, "New Value 3");
+        value = (String) dynaForm.get("stringArray", 3);
+        assertNotNull("Returned new value 3", value);
+        assertTrue("Returned String new value 3",
+                value instanceof String);
+        assertEquals("Returned correct new value 3", "New Value 3",
+                (String) value);
 
-        try {
-            dynaForm.set("stringArray", 3, "New Value 3");
-            value = (String) dynaForm.get("stringArray", 3);
-            assertNotNull("Returned new value 3", value);
-            assertTrue("Returned String new value 3",
-                    value instanceof String);
-            assertEquals("Returned correct new value 3", "New Value 3",
-                    (String) value);
-        } catch (Throwable t) {
-            fail("Threw " + t);
-        }
-
-        try {
-            dynaForm.set("stringIndexed", 4, "New Value 4");
-            value = (String) dynaForm.get("stringIndexed", 4);
-            assertNotNull("Returned new value 4", value);
-            assertTrue("Returned String new value 4",
-                    value instanceof String);
-            assertEquals("Returned correct new value 4", "New Value 4",
-                    (String) value);
-        } catch (Throwable t) {
-            fail("Threw " + t);
-        }
+        dynaForm.set("stringIndexed", 4, "New Value 4");
+        value = (String) dynaForm.get("stringIndexed", 4);
+        assertNotNull("Returned new value 4", value);
+        assertTrue("Returned String new value 4",
+                value instanceof String);
+        assertEquals("Returned correct new value 4", "New Value 4",
+                (String) value);
 
 
     }
@@ -837,25 +686,16 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testSetMappedValues() {
 
-        Object value = null;
 
-        try {
-            dynaForm.set("mappedProperty", "First Key", "New First Value");
-            assertEquals("Can replace old value",
-                    "New First Value",
-                    (String) dynaForm.get("mappedProperty", "First Key"));
-        } catch (Throwable t) {
-            fail("Finding fourth value threw " + t);
-        }
+        dynaForm.set("mappedProperty", "First Key", "New First Value");
+        assertEquals("Can replace old value",
+                "New First Value",
+                (String) dynaForm.get("mappedProperty", "First Key"));
 
-        try {
-            dynaForm.set("mappedProperty", "Fourth Key", "Fourth Value");
-            assertEquals("Can set new value",
-                    "Fourth Value",
-                    (String) dynaForm.get("mappedProperty", "Fourth Key"));
-        } catch (Throwable t) {
-            fail("Finding fourth value threw " + t);
-        }
+        dynaForm.set("mappedProperty", "Fourth Key", "Fourth Value");
+        assertEquals("Can set new value",
+                "Fourth Value",
+                (String) dynaForm.get("mappedProperty", "Fourth Key"));
 
 
     }
@@ -866,17 +706,13 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testSetSimpleBoolean() {
 
-        try {
-            boolean oldValue =
-                    ((Boolean) dynaForm.get("booleanProperty")).booleanValue();
-            boolean newValue = !oldValue;
-            dynaForm.set("booleanProperty", new Boolean(newValue));
-            assertTrue("Matched new value",
-                    newValue ==
-                    ((Boolean) dynaForm.get("booleanProperty")).booleanValue());
-        } catch (Throwable e) {
-            fail("Exception: " + e);
-        }
+        boolean oldValue =
+                ((Boolean) dynaForm.get("booleanProperty")).booleanValue();
+        boolean newValue = !oldValue;
+        dynaForm.set("booleanProperty", new Boolean(newValue));
+        assertTrue("Matched new value",
+                newValue ==
+                ((Boolean) dynaForm.get("booleanProperty")).booleanValue());
 
     }
 
@@ -886,18 +722,14 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testSetSimpleDouble() {
 
-        try {
-            double oldValue =
-                    ((Double) dynaForm.get("doubleProperty")).doubleValue();
-            double newValue = oldValue + 1.0;
-            dynaForm.set("doubleProperty", new Double(newValue));
-            assertEquals("Matched new value",
-                    newValue,
-                    ((Double) dynaForm.get("doubleProperty")).doubleValue(),
-                    (double) 0.005);
-        } catch (Throwable e) {
-            fail("Exception: " + e);
-        }
+        double oldValue =
+                ((Double) dynaForm.get("doubleProperty")).doubleValue();
+        double newValue = oldValue + 1.0;
+        dynaForm.set("doubleProperty", new Double(newValue));
+        assertEquals("Matched new value",
+                newValue,
+                ((Double) dynaForm.get("doubleProperty")).doubleValue(),
+                (double) 0.005);
 
     }
 
@@ -907,18 +739,14 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testSetSimpleFloat() {
 
-        try {
-            float oldValue =
-                    ((Float) dynaForm.get("floatProperty")).floatValue();
-            float newValue = oldValue + (float) 1.0;
-            dynaForm.set("floatProperty", new Float(newValue));
-            assertEquals("Matched new value",
-                    newValue,
-                    ((Float) dynaForm.get("floatProperty")).floatValue(),
-                    (float) 0.005);
-        } catch (Throwable e) {
-            fail("Exception: " + e);
-        }
+        float oldValue =
+                ((Float) dynaForm.get("floatProperty")).floatValue();
+        float newValue = oldValue + (float) 1.0;
+        dynaForm.set("floatProperty", new Float(newValue));
+        assertEquals("Matched new value",
+                newValue,
+                ((Float) dynaForm.get("floatProperty")).floatValue(),
+                (float) 0.005);
 
     }
 
@@ -928,18 +756,13 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testSetSimpleInt() {
 
-        try {
-            int oldValue =
-                    ((Integer) dynaForm.get("intProperty")).intValue();
-            int newValue = oldValue + 1;
-            dynaForm.set("intProperty", new Integer(newValue));
-            assertEquals("Matched new value",
-                    newValue,
-                    ((Integer) dynaForm.get("intProperty")).intValue());
-        } catch (Throwable e) {
-            fail("Exception: " + e);
-        }
-
+        int oldValue =
+                ((Integer) dynaForm.get("intProperty")).intValue();
+        int newValue = oldValue + 1;
+        dynaForm.set("intProperty", new Integer(newValue));
+        assertEquals("Matched new value",
+                newValue,
+                ((Integer) dynaForm.get("intProperty")).intValue());
     }
 
 
@@ -948,17 +771,13 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testSetSimpleLong() {
 
-        try {
-            long oldValue =
-                    ((Long) dynaForm.get("longProperty")).longValue();
-            long newValue = oldValue + 1;
-            dynaForm.set("longProperty", new Long(newValue));
-            assertEquals("Matched new value",
-                    newValue,
-                    ((Long) dynaForm.get("longProperty")).longValue());
-        } catch (Throwable e) {
-            fail("Exception: " + e);
-        }
+        long oldValue =
+                ((Long) dynaForm.get("longProperty")).longValue();
+        long newValue = oldValue + 1;
+        dynaForm.set("longProperty", new Long(newValue));
+        assertEquals("Matched new value",
+                newValue,
+                ((Long) dynaForm.get("longProperty")).longValue());
 
     }
 
@@ -968,17 +787,13 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testSetSimpleShort() {
 
-        try {
-            short oldValue =
-                    ((Short) dynaForm.get("shortProperty")).shortValue();
-            short newValue = (short) (oldValue + 1);
-            dynaForm.set("shortProperty", new Short(newValue));
-            assertEquals("Matched new value",
-                    newValue,
-                    ((Short) dynaForm.get("shortProperty")).shortValue());
-        } catch (Throwable e) {
-            fail("Exception: " + e);
-        }
+        short oldValue =
+                ((Short) dynaForm.get("shortProperty")).shortValue();
+        short newValue = (short) (oldValue + 1);
+        dynaForm.set("shortProperty", new Short(newValue));
+        assertEquals("Matched new value",
+                newValue,
+                ((Short) dynaForm.get("shortProperty")).shortValue());
 
     }
 
@@ -988,16 +803,12 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     public void testSetSimpleString() {
 
-        try {
-            String oldValue = (String) dynaForm.get("stringProperty");
-            String newValue = oldValue + " Extra Value";
-            dynaForm.set("stringProperty", newValue);
-            assertEquals("Matched new value",
-                    newValue,
-                    (String) dynaForm.get("stringProperty"));
-        } catch (Throwable e) {
-            fail("Exception: " + e);
-        }
+        String oldValue = (String) dynaForm.get("stringProperty");
+        String newValue = oldValue + " Extra Value";
+        dynaForm.set("stringProperty", newValue);
+        assertEquals("Matched new value",
+                newValue,
+                (String) dynaForm.get("stringProperty"));
 
     }
 
@@ -1041,14 +852,10 @@ public class TestDynaActionForm extends TestDynaActionFormClass {
      */
     protected void testGetDescriptorBase(String name, Class type) {
 
-        try {
-            DynaProperty descriptor =
-                    dynaForm.getDynaClass().getDynaProperty(name);
-            assertNotNull("Got descriptor", descriptor);
-            assertEquals("Got correct type", type, descriptor.getType());
-        } catch (Throwable t) {
-            fail("Threw an exception: " + t);
-        }
+        DynaProperty descriptor =
+                dynaForm.getDynaClass().getDynaProperty(name);
+        assertNotNull("Got descriptor", descriptor);
+        assertEquals("Got correct type", type, descriptor.getType());
 
     }
 
@@ -1076,7 +883,7 @@ class DynaActionFormMapping extends ActionMapping {
 
 
 
-class DynaActionFormConfig extends ApplicationConfig {
+class DynaActionFormConfig extends ModuleConfigImpl {
 
     public DynaActionFormConfig(FormBeanConfig beanConfig) {
         super("");
@@ -1088,8 +895,8 @@ class DynaActionFormConfig extends ApplicationConfig {
     public FormBeanConfig findFormBeanConfig(String name) {
         return (this.beanConfig);
     }
-    
-	
+
+
 }
 
 
