@@ -1,61 +1,21 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/test/org/apache/struts/taglib/logic/TestIterateTag.java,v 1.5 2003/05/13 18:21:14 turner Exp $
- * $Revision: 1.5 $
- * $Date: 2003/05/13 18:21:14 $
+ * $Header: /home/cvs/jakarta-struts/src/test/org/apache/struts/taglib/logic/TestIterateTag.java,v 1.9 2004/07/01 00:52:02 husted Exp $
+ * $Revision: 1.9 $
+ * $Date: 2004/07/01 00:52:02 $
+ *
+ * Copyright 1999-2004 The Apache Software Foundation.
  * 
- * ====================================================================
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package org.apache.struts.taglib.logic;
 
@@ -67,20 +27,20 @@ import java.util.StringTokenizer;
 import javax.servlet.ServletException;
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.PageContext;
+
 import junit.framework.Test;
 import junit.framework.TestSuite;
 
 import org.apache.cactus.JspTestCase;
 import org.apache.cactus.WebResponse;
-import org.apache.struts.taglib.SimpleBeanForTesting;
 import org.apache.commons.lang.StringUtils;
+import org.apache.struts.taglib.SimpleBeanForTesting;
 
 
 /**
  * Suite of unit tests for the
  * <code>org.apache.struts.taglib.logic.IterateTag</code> class.
  *
- * @author James Mitchell
  */
 public class TestIterateTag extends JspTestCase {
 	
@@ -152,7 +112,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print((String)pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -199,7 +159,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print((String)pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -246,7 +206,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print((String)pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -314,7 +274,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print((String)pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -372,7 +332,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print((String)pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -430,7 +390,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print((String)pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -484,7 +444,7 @@ public class TestIterateTag extends JspTestCase {
 		{
 			out.print((String)pageContext.getAttribute("theId"));
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 
 	}
@@ -528,7 +488,7 @@ public class TestIterateTag extends JspTestCase {
 		{
 			out.print((String)pageContext.getAttribute("theId"));
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 
 	}
@@ -572,7 +532,7 @@ public class TestIterateTag extends JspTestCase {
 		{
 			out.print((String)pageContext.getAttribute("theId"));
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 
 	}
@@ -631,7 +591,7 @@ public class TestIterateTag extends JspTestCase {
 		{
 			out.print((String)pageContext.getAttribute("theId"));
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 
 	}
@@ -679,7 +639,7 @@ public class TestIterateTag extends JspTestCase {
 		{
 			out.print((String)pageContext.getAttribute("theId"));
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 
 	}
@@ -727,7 +687,7 @@ public class TestIterateTag extends JspTestCase {
 		{
 			out.print((String)pageContext.getAttribute("theId"));
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 
 	}
@@ -790,7 +750,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -837,7 +797,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -884,7 +844,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -948,7 +908,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -999,7 +959,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -1050,7 +1010,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -1111,7 +1071,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -1163,7 +1123,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -1215,7 +1175,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -1281,7 +1241,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -1337,7 +1297,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
@@ -1393,7 +1353,7 @@ public class TestIterateTag extends JspTestCase {
 			out.print(pageContext.getAttribute("theId"));
 		    iteration++;
 		
-		} while (tag.doAfterBody() == tag.EVAL_BODY_TAG);
+		} while (tag.doAfterBody() == IterateTag.EVAL_BODY_TAG);
 		tag.doEndTag();
 		assertEquals(iterations, iteration);
 	}
