@@ -1,62 +1,21 @@
 /*
- * $Header: /home/cvs/jakarta-struts/src/test/org/apache/struts/util/TestRequestUtils.java,v 1.18 2003/05/04 22:41:13 dgraham Exp $
- * $Revision: 1.18 $
- * $Date: 2003/05/04 22:41:13 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Struts", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * $Header: /home/cvs/jakarta-struts/src/test/org/apache/struts/util/TestRequestUtils.java,v 1.26 2004/03/14 06:23:54 sraeburn Exp $
+ * $Revision: 1.26 $
+ * $Date: 2004/03/14 06:23:54 $
  *
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
@@ -68,17 +27,17 @@ import java.util.HashMap;
 import java.util.Map;
 
 import javax.servlet.jsp.JspException;
+
 import junit.framework.Test;
 import junit.framework.TestSuite;
 
 import org.apache.struts.Globals;
-import org.apache.struts.action.Action;
 import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
 import org.apache.struts.action.DynaActionForm;
 import org.apache.struts.action.RequestProcessor;
-import org.apache.struts.config.ApplicationConfig;
 import org.apache.struts.config.ForwardConfig;
+import org.apache.struts.config.ModuleConfig;
 import org.apache.struts.mock.MockFormBean;
 import org.apache.struts.mock.MockPrincipal;
 import org.apache.struts.mock.TestMockBase;
@@ -88,8 +47,7 @@ import org.apache.struts.taglib.html.Constants;
 /**
  * <p>Unit tests for <code>org.apache.struts.util.RequestUtils</code>.</p>
  *
- * @author Craig R. McClanahan
- * @version $Revision: 1.18 $ $Date: 2003/05/04 22:41:13 $
+ * @version $Revision: 1.26 $ $Date: 2004/03/14 06:23:54 $
  */
 
 public class TestRequestUtils extends TestMockBase {
@@ -163,10 +121,10 @@ public class TestRequestUtils extends TestMockBase {
     // Default application -- extension mapping
     public void testActionURL1() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig);
         request.setPathElements("/myapp", "/foo.do", null, null);
         String url = RequestUtils.actionURL
-            (request, appConfig.findActionConfig("/dynamic"), "*.do");
+            (request, moduleConfig.findActionConfig("/dynamic"), "*.do");
         assertNotNull("URL was returned", url);
         assertEquals("URL value",
                      "/dynamic.do",
@@ -178,10 +136,10 @@ public class TestRequestUtils extends TestMockBase {
     // Second application -- extension mapping
     public void testActionURL2() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/foo.do", null, null);
         String url = RequestUtils.actionURL
-            (request, appConfig2.findActionConfig("/dynamic2"), "*.do");
+            (request, moduleConfig2.findActionConfig("/dynamic2"), "*.do");
         assertNotNull("URL was returned", url);
         assertEquals("URL value",
                      "/2/dynamic2.do",
@@ -193,10 +151,10 @@ public class TestRequestUtils extends TestMockBase {
     // Default application -- path mapping
     public void testActionURL3() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig);
         request.setPathElements("/myapp", "/do/foo", null, null);
         String url = RequestUtils.actionURL
-            (request, appConfig.findActionConfig("/dynamic"), "/do/*");
+            (request, moduleConfig.findActionConfig("/dynamic"), "/do/*");
         assertNotNull("URL was returned", url);
         assertEquals("URL value",
                      "/do/dynamic",
@@ -552,7 +510,7 @@ public class TestRequestUtils extends TestMockBase {
     // Default module -- Forward with pattern
     public void testComputeURL1d() {
 
-        appConfig.getControllerConfig().setForwardPattern
+        moduleConfig.getControllerConfig().setForwardPattern
             ("$C/WEB-INF/pages$M$P");
         request.setPathElements("/myapp", "/action.do", null, null);
         String url = null;
@@ -575,7 +533,7 @@ public class TestRequestUtils extends TestMockBase {
     // Default module -- Page with pattern
     public void testComputeURL1e() {
 
-        appConfig.getControllerConfig().setPagePattern
+        moduleConfig.getControllerConfig().setPagePattern
             ("$C/WEB-INF/pages$M$P");
         request.setPathElements("/myapp", "/action.do", null, null);
         String url = null;
@@ -660,7 +618,7 @@ public class TestRequestUtils extends TestMockBase {
     // Second module -- Forward only
     public void testComputeURL2a() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String url = null;
         try {
@@ -682,7 +640,7 @@ public class TestRequestUtils extends TestMockBase {
     // Second module -- Href only
     public void testComputeURL2b() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String url = null;
         try {
@@ -704,7 +662,7 @@ public class TestRequestUtils extends TestMockBase {
     // Second module -- Page only
     public void testComputeURL2c() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String url = null;
         try {
@@ -726,8 +684,8 @@ public class TestRequestUtils extends TestMockBase {
     // Default module -- Forward with pattern
     public void testComputeURL2d() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
-        appConfig2.getControllerConfig().setForwardPattern
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
+        moduleConfig2.getControllerConfig().setForwardPattern
             ("$C/WEB-INF/pages$M$P");
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String url = null;
@@ -750,9 +708,9 @@ public class TestRequestUtils extends TestMockBase {
     // Second module -- Page with pattern
     public void testComputeURL2e() {
 
-        appConfig2.getControllerConfig().setPagePattern
+        moduleConfig2.getControllerConfig().setPagePattern
             ("$C/WEB-INF/pages$M$P");
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String url = null;
         try {
@@ -774,7 +732,7 @@ public class TestRequestUtils extends TestMockBase {
     // Second module -- Forward with relative path (non-context-relative)
     public void testComputeURL2f() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String url = null;
         try {
@@ -796,7 +754,7 @@ public class TestRequestUtils extends TestMockBase {
     // Second module -- Forward with relative path (context-relative)
     public void testComputeURL2g() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String url = null;
         try {
@@ -818,7 +776,7 @@ public class TestRequestUtils extends TestMockBase {
     // Second module -- Forward with external path
     public void testComputeURL2h() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String url = null;
         try {
@@ -983,10 +941,10 @@ public class TestRequestUtils extends TestMockBase {
 
         request.setPathElements("/myapp", "/noform.do", null, null);
         ActionMapping mapping = (ActionMapping)
-            appConfig.findActionConfig("/noform");
+            moduleConfig.findActionConfig("/noform");
         assertNotNull("Found /noform mapping", mapping);
         ActionForm form = RequestUtils.createActionForm
-            (request, mapping, appConfig, null);
+            (request, mapping, moduleConfig, null);
         assertNull("No ActionForm returned", form);
 
     }
@@ -997,10 +955,10 @@ public class TestRequestUtils extends TestMockBase {
 
         request.setPathElements("/myapp", "/2/noform.do", null, null);
         ActionMapping mapping = (ActionMapping)
-            appConfig2.findActionConfig("/noform");
+            moduleConfig2.findActionConfig("/noform");
         assertNotNull("Found /noform mapping", mapping);
         ActionForm form = RequestUtils.createActionForm
-            (request, mapping, appConfig2, null);
+            (request, mapping, moduleConfig2, null);
         assertNull("No ActionForm returned", form);
 
     }
@@ -1011,7 +969,7 @@ public class TestRequestUtils extends TestMockBase {
 
         request.setPathElements("/myapp", "/static.do", null, null);
         ActionMapping mapping = (ActionMapping)
-            appConfig.findActionConfig("/static");
+            moduleConfig.findActionConfig("/static");
         assertNotNull("Found /static mapping", mapping);
         assertNotNull("Mapping has non-null name",
                       mapping.getName());
@@ -1019,9 +977,9 @@ public class TestRequestUtils extends TestMockBase {
                      "static",
                      mapping.getName());
         assertNotNull("AppConfig has form bean " + mapping.getName(),
-                      appConfig.findFormBeanConfig(mapping.getName()));
+                      moduleConfig.findFormBeanConfig(mapping.getName()));
         ActionForm form = RequestUtils.createActionForm
-            (request, mapping, appConfig, null);
+            (request, mapping, moduleConfig, null);
         assertNotNull("ActionForm returned", form);
         assertTrue("ActionForm of correct type",
                    form instanceof MockFormBean);
@@ -1034,7 +992,7 @@ public class TestRequestUtils extends TestMockBase {
 
         request.setPathElements("/myapp", "/2/static.do", null, null);
         ActionMapping mapping = (ActionMapping)
-            appConfig2.findActionConfig("/static");
+            moduleConfig2.findActionConfig("/static");
         assertNotNull("Found /static mapping", mapping);
         assertNotNull("Mapping has non-null name",
                       mapping.getName());
@@ -1042,9 +1000,9 @@ public class TestRequestUtils extends TestMockBase {
                      "static",
                      mapping.getName());
         assertNotNull("AppConfig has form bean " + mapping.getName(),
-                      appConfig.findFormBeanConfig(mapping.getName()));
+                      moduleConfig.findFormBeanConfig(mapping.getName()));
         ActionForm form = RequestUtils.createActionForm
-            (request, mapping, appConfig2, null);
+            (request, mapping, moduleConfig2, null);
         assertNotNull("ActionForm returned", form);
         assertTrue("ActionForm of correct type",
                    form instanceof MockFormBean);
@@ -1057,7 +1015,7 @@ public class TestRequestUtils extends TestMockBase {
 
         request.setPathElements("/myapp", "/dynamic.do", null, null);
         ActionMapping mapping = (ActionMapping)
-            appConfig.findActionConfig("/dynamic");
+            moduleConfig.findActionConfig("/dynamic");
         assertNotNull("Found /dynamic mapping", mapping);
         assertNotNull("Mapping has non-null name",
                       mapping.getName());
@@ -1065,9 +1023,9 @@ public class TestRequestUtils extends TestMockBase {
                      "dynamic",
                      mapping.getName());
         assertNotNull("AppConfig has form bean " + mapping.getName(),
-                      appConfig.findFormBeanConfig(mapping.getName()));
+                      moduleConfig.findFormBeanConfig(mapping.getName()));
         ActionForm form = RequestUtils.createActionForm
-            (request, mapping, appConfig, null);
+            (request, mapping, moduleConfig, null);
         assertNotNull("ActionForm returned", form);
         assertTrue("ActionForm of correct type",
                    form instanceof DynaActionForm);
@@ -1080,7 +1038,7 @@ public class TestRequestUtils extends TestMockBase {
 
         request.setPathElements("/myapp", "/2/dynamic2.do", null, null);
         ActionMapping mapping = (ActionMapping)
-            appConfig2.findActionConfig("/dynamic2");
+            moduleConfig2.findActionConfig("/dynamic2");
         assertNotNull("Found /dynamic2 mapping", mapping);
         assertNotNull("Mapping has non-null name",
                       mapping.getName());
@@ -1088,9 +1046,9 @@ public class TestRequestUtils extends TestMockBase {
                      "dynamic2",
                      mapping.getName());
         assertNotNull("AppConfig has form bean " + mapping.getName(),
-                      appConfig2.findFormBeanConfig(mapping.getName()));
+                      moduleConfig2.findFormBeanConfig(mapping.getName()));
         ActionForm form = RequestUtils.createActionForm
-            (request, mapping, appConfig2, null);
+            (request, mapping, moduleConfig2, null);
         assertNotNull("ActionForm returned", form);
         assertTrue("ActionForm of correct type",
                    form instanceof DynaActionForm);
@@ -1104,7 +1062,7 @@ public class TestRequestUtils extends TestMockBase {
         // Retrieve an appropriately configured DynaActionForm instance
         request.setPathElements("/myapp", "/dynamic0.do", null, null);
         ActionMapping mapping = (ActionMapping)
-            appConfig.findActionConfig("/dynamic0");
+            moduleConfig.findActionConfig("/dynamic0");
         assertNotNull("Found /dynamic0 mapping", mapping);
         assertNotNull("Mapping has non-null name",
                       mapping.getName());
@@ -1112,9 +1070,9 @@ public class TestRequestUtils extends TestMockBase {
                      "dynamic0",
                      mapping.getName());
         assertNotNull("AppConfig has form bean " + mapping.getName(),
-                      appConfig.findFormBeanConfig(mapping.getName()));
+                      moduleConfig.findFormBeanConfig(mapping.getName()));
         ActionForm form = RequestUtils.createActionForm
-            (request, mapping, appConfig, null);
+            (request, mapping, moduleConfig, null);
         assertNotNull("ActionForm returned", form);
         assertTrue("ActionForm of correct type",
                    form instanceof DynaActionForm);
@@ -1181,7 +1139,7 @@ public class TestRequestUtils extends TestMockBase {
         // Different form beans should get different property value instances
         Object value1 = null;
         DynaActionForm dform1 = (DynaActionForm)
-            RequestUtils.createActionForm(request, mapping, appConfig, null);
+            RequestUtils.createActionForm(request, mapping, moduleConfig, null);
 
         value = dform.get("principal");
         value1 = dform1.get("principal");
@@ -1211,60 +1169,60 @@ public class TestRequestUtils extends TestMockBase {
     // Default module (default forwardPattern)
     public void testForwardURL1() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig);
         request.setPathElements("/myapp", "/action.do", null, null);
         ForwardConfig forward = null;
         String result = null;
 
         // redirect=false, contextRelative=false
-        forward = appConfig.findForwardConfig("moduleForward");
+        forward = moduleConfig.findForwardConfig("moduleForward");
         assertNotNull("moduleForward found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleForward computed", result);
         assertEquals("moduleForward value",
                      "/module/forward",
                      result);
 
         // redirect=true, contextRelative=false
-        forward = appConfig.findForwardConfig("moduleRedirect");
+        forward = moduleConfig.findForwardConfig("moduleRedirect");
         assertNotNull("moduleRedirect found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleRedirect computed", result);
         assertEquals("moduleRedirect value",
                      "/module/redirect",
                      result);
 
         // redirect=false, contextRelative=true
-        forward = appConfig.findForwardConfig("contextForward");
+        forward = moduleConfig.findForwardConfig("contextForward");
         assertNotNull("contextForward found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextForward computed", result);
         assertEquals("contextForward value",
                      "/context/forward",
                      result);
 
         // redirect=true, contextRelative=true
-        forward = appConfig.findForwardConfig("contextRedirect");
+        forward = moduleConfig.findForwardConfig("contextRedirect");
         assertNotNull("contextRedirect found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextRedirect computed", result);
         assertEquals("contextRedirct value",
                      "/context/redirect",
                      result);
 
         // noslash, contextRelative=false
-        forward = appConfig.findForwardConfig("moduleNoslash");
+        forward = moduleConfig.findForwardConfig("moduleNoslash");
         assertNotNull("moduleNoslash found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleNoslash computed", result);
         assertEquals("moduleNoslash value",
                      "/module/noslash",
                      result);
 
         // noslash, contextRelative=true
-        forward = appConfig.findForwardConfig("contextNoslash");
+        forward = moduleConfig.findForwardConfig("contextNoslash");
         assertNotNull("contextNoslash found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextNoslash computed", result);
         assertEquals("contextNoslash value",
                      "/context/noslash",
@@ -1276,60 +1234,60 @@ public class TestRequestUtils extends TestMockBase {
     // Second module (default forwardPattern)
     public void testForwardURL2() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         ForwardConfig forward = null;
         String result = null;
 
         // redirect=false, contextRelative=false
-        forward = appConfig2.findForwardConfig("moduleForward");
+        forward = moduleConfig2.findForwardConfig("moduleForward");
         assertNotNull("moduleForward found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleForward computed", result);
         assertEquals("moduleForward value",
                      "/2/module/forward",
                      result);
 
         // redirect=true, contextRelative=false
-        forward = appConfig2.findForwardConfig("moduleRedirect");
+        forward = moduleConfig2.findForwardConfig("moduleRedirect");
         assertNotNull("moduleRedirect found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleRedirect computed", result);
         assertEquals("moduleRedirect value",
                      "/2/module/redirect",
                      result);
 
         // redirect=false, contextRelative=true
-        forward = appConfig2.findForwardConfig("contextForward");
+        forward = moduleConfig2.findForwardConfig("contextForward");
         assertNotNull("contextForward found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextForward computed", result);
         assertEquals("contextForward value",
                      "/context/forward",
                      result);
 
         // redirect=true, contextRelative=true
-        forward = appConfig2.findForwardConfig("contextRedirect");
+        forward = moduleConfig2.findForwardConfig("contextRedirect");
         assertNotNull("contextRedirect found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextRedirect computed", result);
         assertEquals("contextRedirct value",
                      "/context/redirect",
                      result);
 
         // noslash, contextRelative=false
-        forward = appConfig2.findForwardConfig("moduleNoslash");
+        forward = moduleConfig2.findForwardConfig("moduleNoslash");
         assertNotNull("moduleNoslash found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleNoslash computed", result);
         assertEquals("moduleNoslash value",
                      "/2/module/noslash",
                      result);
 
         // noslash, contextRelative=true
-        forward = appConfig2.findForwardConfig("contextNoslash");
+        forward = moduleConfig2.findForwardConfig("contextNoslash");
         assertNotNull("contextNoslash found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextNoslash computed", result);
         assertEquals("contextNoslash value",
                      "/context/noslash",
@@ -1341,60 +1299,60 @@ public class TestRequestUtils extends TestMockBase {
     // Third module (custom forwardPattern)
     public void testForwardURL3() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig3);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig3);
         request.setPathElements("/myapp", "/3/action.do", null, null);
         ForwardConfig forward = null;
         String result = null;
 
         // redirect=false, contextRelative=false
-        forward = appConfig3.findForwardConfig("moduleForward");
+        forward = moduleConfig3.findForwardConfig("moduleForward");
         assertNotNull("moduleForward found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleForward computed", result);
         assertEquals("moduleForward value",
                      "/forwarding/3/module/forward",
                      result);
 
         // redirect=true, contextRelative=false
-        forward = appConfig3.findForwardConfig("moduleRedirect");
+        forward = moduleConfig3.findForwardConfig("moduleRedirect");
         assertNotNull("moduleRedirect found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleRedirect computed", result);
         assertEquals("moduleRedirect value",
                      "/forwarding/3/module/redirect",
                      result);
 
         // redirect=false, contextRelative=true
-        forward = appConfig3.findForwardConfig("contextForward");
+        forward = moduleConfig3.findForwardConfig("contextForward");
         assertNotNull("contextForward found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextForward computed", result);
         assertEquals("contextForward value",
                      "/context/forward",
                      result);
 
         // redirect=true, contextRelative=true
-        forward = appConfig3.findForwardConfig("contextRedirect");
+        forward = moduleConfig3.findForwardConfig("contextRedirect");
         assertNotNull("contextRedirect found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextRedirect computed", result);
         assertEquals("contextRedirct value",
                      "/context/redirect",
                      result);
 
         // noslash, contextRelative=false
-        forward = appConfig3.findForwardConfig("moduleNoslash");
+        forward = moduleConfig3.findForwardConfig("moduleNoslash");
         assertNotNull("moduleNoslash found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("moduleNoslash computed", result);
         assertEquals("moduleNoslash value",
                      "/forwarding/3/module/noslash",
                      result);
 
         // noslash, contextRelative=true
-        forward = appConfig3.findForwardConfig("contextNoslash");
+        forward = moduleConfig3.findForwardConfig("contextNoslash");
         assertNotNull("contextNoslash found", forward);
-        result = RequestUtils.forwardURL(request, forward);
+        result = RequestUtils.forwardURL(request, forward, null);
         assertNotNull("contextNoslash computed", result);
         assertEquals("contextNoslash value",
                      "/context/noslash",
@@ -1403,13 +1361,78 @@ public class TestRequestUtils extends TestMockBase {
     }
 
 
+	// Cross module forwards
+	public void testForwardURLa() {
+
+		request.setAttribute(Globals.MODULE_KEY, moduleConfig);
+		request.setPathElements("/myapp", "/action.do", null, null);
+		ForwardConfig forward = null;
+		String result = null;
+
+		// redirect=false, contextRelative=false, link to module 3
+		forward = moduleConfig3.findForwardConfig("moduleForward");
+		assertNotNull("moduleForward found", forward);
+		result = RequestUtils.forwardURL(request, forward, moduleConfig3);
+		assertNotNull("moduleForward computed", result);
+		assertEquals("moduleForward value",
+					 "/forwarding/3/module/forward",
+					 result);
+
+		// redirect=true, contextRelative=false, link to module 3
+		forward = moduleConfig3.findForwardConfig("moduleRedirect");
+		assertNotNull("moduleRedirect found", forward);
+		result = RequestUtils.forwardURL(request, forward, moduleConfig3);
+		assertNotNull("moduleRedirect computed", result);
+		assertEquals("moduleRedirect value",
+					 "/forwarding/3/module/redirect",
+					 result);
+
+		// redirect=false, contextRelative=true, link to module 3
+		forward = moduleConfig3.findForwardConfig("contextForward");
+		assertNotNull("contextForward found", forward);
+		result = RequestUtils.forwardURL(request, forward, moduleConfig3);
+		assertNotNull("contextForward computed", result);
+		assertEquals("contextForward value",
+					 "/context/forward",
+					 result);
+
+		// redirect=true, contextRelative=true, link to module 3
+		forward = moduleConfig3.findForwardConfig("contextRedirect");
+		assertNotNull("contextRedirect found", forward);
+		result = RequestUtils.forwardURL(request, forward, moduleConfig3);
+		assertNotNull("contextRedirect computed", result);
+		assertEquals("contextRedirct value",
+					 "/context/redirect",
+					 result);
+
+		// noslash, contextRelative=false, link to module 3
+		forward = moduleConfig3.findForwardConfig("moduleNoslash");
+		assertNotNull("moduleNoslash found", forward);
+		result = RequestUtils.forwardURL(request, forward, moduleConfig3);
+		assertNotNull("moduleNoslash computed", result);
+		assertEquals("moduleNoslash value",
+					 "/forwarding/3/module/noslash",
+					 result);
+
+		// noslash, contextRelative=true, link to module 3
+		forward = moduleConfig3.findForwardConfig("contextNoslash");
+		assertNotNull("contextNoslash found", forward);
+		result = RequestUtils.forwardURL(request, forward, moduleConfig3);
+		assertNotNull("contextNoslash computed", result);
+		assertEquals("contextNoslash value",
+					 "/context/noslash",
+					 result);
+
+	}
+
+
     // -------------------------------------------------------------- pageURL()
 
 
     // Default module (default pagePattern)
     public void testPageURL1() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig);
         request.setPathElements("/myapp", "/action.do", null, null);
         String page = null;
         String result = null;
@@ -1428,7 +1451,7 @@ public class TestRequestUtils extends TestMockBase {
     // Second module (default pagePattern)
     public void testPageURL2() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig2);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig2);
         request.setPathElements("/myapp", "/2/action.do", null, null);
         String page = null;
         String result = null;
@@ -1447,7 +1470,7 @@ public class TestRequestUtils extends TestMockBase {
     // Third module (custom pagePattern)
     public void testPageURL3() {
 
-        request.setAttribute(Globals.MODULE_KEY, appConfig3);
+        request.setAttribute(Globals.MODULE_KEY, moduleConfig3);
         request.setPathElements("/myapp", "/3/action.do", null, null);
         String page = null;
         String result = null;
@@ -1490,28 +1513,30 @@ public class TestRequestUtils extends TestMockBase {
     public void testSelectApplication1a() {
 
         request.setPathElements("/myapp", "/noform.do", null, null);
-        RequestUtils.selectApplication(request, context);
-        ApplicationConfig appConfig = (ApplicationConfig)
+        ModuleUtils.getInstance().selectModule(request, context);
+        ModuleConfig moduleConfig = (ModuleConfig)
             request.getAttribute(Globals.MODULE_KEY);
-        assertNotNull("Selected an application", appConfig);
-        assertEquals("Selected correct application",
-                     "", appConfig.getPrefix());
-        // FIXME - check application resources?
+        assertNotNull("Selected a module", moduleConfig);
+        assertEquals("Selected correct module",
+                     "", moduleConfig.getPrefix());
+        // FIXME - check module resources?
 
     }
 
 
     // Map to the second module -- direct
     public void testSelectApplication1b() {
-
+        String[] prefixes = { "/1", "/2" };
+        context.setAttribute(Globals.MODULE_PREFIXES_KEY, prefixes);    
         request.setPathElements("/myapp", "/2/noform.do", null, null);
-        RequestUtils.selectApplication(request, context);
-        ApplicationConfig appConfig = (ApplicationConfig)
+        
+        ModuleUtils.getInstance().selectModule(request, context);
+        ModuleConfig moduleConfig = (ModuleConfig)
             request.getAttribute(Globals.MODULE_KEY);
-        assertNotNull("Selected an application", appConfig);
-        assertEquals("Selected correct application",
-                     "/2", appConfig.getPrefix());
-        // FIXME - check application resources?
+        assertNotNull("Selected a module", moduleConfig);
+        assertEquals("Selected correct module",
+                     "/2", moduleConfig.getPrefix());
+        // FIXME - check module resources?
 
     }
 
@@ -1522,12 +1547,12 @@ public class TestRequestUtils extends TestMockBase {
         request.setPathElements("/myapp", "/2/noform.do", null, null);
         request.setAttribute(RequestProcessor.INCLUDE_SERVLET_PATH,
                              "/noform.do");
-        RequestUtils.selectApplication(request, context);
-        ApplicationConfig appConfig = (ApplicationConfig)
+        ModuleUtils.getInstance().selectModule(request, context);
+        ModuleConfig moduleConfig = (ModuleConfig)
             request.getAttribute(Globals.MODULE_KEY);
-        assertNotNull("Selected an application", appConfig);
+        assertNotNull("Selected an application", moduleConfig);
         assertEquals("Selected correct application",
-                     "", appConfig.getPrefix());
+                     "", moduleConfig.getPrefix());
         // FIXME - check application resources?
 
     }
@@ -1535,16 +1560,17 @@ public class TestRequestUtils extends TestMockBase {
 
     // Map to the second module -- include
     public void testSelectApplication2b() {
-
+        String[] prefixes = { "/1", "/2" };
+        context.setAttribute(Globals.MODULE_PREFIXES_KEY, prefixes);    
         request.setPathElements("/myapp", "/noform.do", null, null);
         request.setAttribute(RequestProcessor.INCLUDE_SERVLET_PATH,
                              "/2/noform.do");
-        RequestUtils.selectApplication(request, context);
-        ApplicationConfig appConfig = (ApplicationConfig)
+        ModuleUtils.getInstance().selectModule(request, context);
+        ModuleConfig moduleConfig = (ModuleConfig)
             request.getAttribute(Globals.MODULE_KEY);
-        assertNotNull("Selected an application", appConfig);
-        assertEquals("Selected correct application",
-                     "/2", appConfig.getPrefix());
+        assertNotNull("Selected a module", moduleConfig);
+        assertEquals("Selected correct module",
+                     "/2", moduleConfig.getPrefix());
         // FIXME - check application resources?
 
     }
